@@ -1,17 +1,16 @@
 """Support for Axis switches."""
 from typing import Any
 
-from axis.event_stream import CLASS_OUTPUT, AxisBinaryEvent, AxisEvent
+from axis.models.event import Event, EventOperation, EventTopic
 
 from homeassistant.components.switch import SwitchEntity
 from homeassistant.config_entries import ConfigEntry
 from homeassistant.core import HomeAssistant, callback
-from homeassistant.helpers.dispatcher import async_dispatcher_connect
 from homeassistant.helpers.entity_platform import AddEntitiesCallback
 
-from .axis_base import AxisEventBase
 from .const import DOMAIN as AXIS_DOMAIN
 from .device import AxisNetworkDevice
+from .entity import AxisEventEntity
 
 
 async def async_setup_entry(
@@ -20,42 +19,41 @@ async def async_setup_entry(
     async_add_entities: AddEntitiesCallback,
 ) -> None:
     """Set up a Axis switch."""
-    device: AxisNetworkDevice = hass.data[AXIS_DOMAIN][config_entry.unique_id]
+    device: AxisNetworkDevice = hass.data[AXIS_DOMAIN][config_entry.entry_id]
 
     @callback
-    def async_add_switch(event_id):
-        """Add switch from Axis device."""
-        event: AxisEvent = device.api.event[event_id]
+    def async_create_entity(event: Event) -> None:
+        """Create Axis switch entity."""
+        async_add_entities([AxisSwitch(event, device)])
 
-        if event.CLASS == CLASS_OUTPUT:
-            async_add_entities([AxisSwitch(event, device)])
-
-    config_entry.async_on_unload(
-        async_dispatcher_connect(hass, device.signal_new_event, async_add_switch)
+    device.api.event.subscribe(
+        async_create_entity,
+        topic_filter=EventTopic.RELAY,
+        operation_filter=EventOperation.INITIALIZED,
     )
 
 
-class AxisSwitch(AxisEventBase, SwitchEntity):
+class AxisSwitch(AxisEventEntity, SwitchEntity):
     """Representation of a Axis switch."""
 
-    event: AxisBinaryEvent
-
-    def __init__(self, event: AxisEvent, device: AxisNetworkDevice) -> None:
+    def __init__(self, event: Event, device: AxisNetworkDevice) -> None:
         """Initialize the Axis switch."""
         super().__init__(event, device)
 
         if event.id and device.api.vapix.ports[event.id].name:
             self._attr_name = device.api.vapix.ports[event.id].name
+        self._attr_is_on = event.is_tripped
 
-    @property
-    def is_on(self) -> bool:
-        """Return true if event is active."""
-        return self.event.is_tripped
+    @callback
+    def async_event_callback(self, event: Event) -> None:
+        """Update light state."""
+        self._attr_is_on = event.is_tripped
+        self.async_write_ha_state()
 
     async def async_turn_on(self, **kwargs: Any) -> None:
         """Turn on switch."""
-        await self.device.api.vapix.ports[self.event.id].close()
+        await self.device.api.vapix.ports[self._event_id].close()
 
     async def async_turn_off(self, **kwargs: Any) -> None:
         """Turn off switch."""
-        await self.device.api.vapix.ports[self.event.id].open()
+        await self.device.api.vapix.ports[self._event_id].open()
