@@ -1,6 +1,8 @@
 """Config flow to configure demo component."""
 from __future__ import annotations
 
+from typing import Any
+
 import voluptuous as vol
 
 from homeassistant import config_entries
@@ -30,9 +32,9 @@ class DemoConfigFlow(config_entries.ConfigFlow, domain=DOMAIN):
         """Get the options flow for this handler."""
         return OptionsFlowHandler(config_entry)
 
-    async def async_step_import(self, import_info) -> FlowResult:
+    async def async_step_import(self, import_info: dict[str, Any]) -> FlowResult:
         """Set the config entry up from yaml."""
-        return self.async_create_entry(title="Demo", data={})
+        return self.async_create_entry(title="Demo", data=import_info)
 
 
 class OptionsFlowHandler(config_entries.OptionsFlow):
@@ -43,11 +45,15 @@ class OptionsFlowHandler(config_entries.OptionsFlow):
         self.config_entry = config_entry
         self.options = dict(config_entry.options)
 
-    async def async_step_init(self, user_input=None) -> FlowResult:
+    async def async_step_init(
+        self, user_input: dict[str, Any] | None = None
+    ) -> FlowResult:
         """Manage the options."""
         return await self.async_step_options_1()
 
-    async def async_step_options_1(self, user_input=None) -> FlowResult:
+    async def async_step_options_1(
+        self, user_input: dict[str, Any] | None = None
+    ) -> FlowResult:
         """Manage the options."""
         if user_input is not None:
             self.options.update(user_input)
@@ -70,7 +76,9 @@ class OptionsFlowHandler(config_entries.OptionsFlow):
             ),
         )
 
-    async def async_step_options_2(self, user_input=None) -> FlowResult:
+    async def async_step_options_2(
+        self, user_input: dict[str, Any] | None = None
+    ) -> FlowResult:
         """Manage the options 2."""
         if user_input is not None:
             self.options.update(user_input)
@@ -101,6 +109,6 @@ class OptionsFlowHandler(config_entries.OptionsFlow):
             ),
         )
 
-    async def _update_options(self):
+    async def _update_options(self) -> FlowResult:
         """Update config entry options."""
         return self.async_create_entry(title="", data=self.options)
