@@ -6,26 +6,30 @@ from collections import defaultdict
 import logging
 from typing import Any
 
+import async_timeout
 from pyforked_daapd import ForkedDaapdAPI
 from pylibrespot_java import LibrespotJavaAPI
 
 from homeassistant.components import media_source
-from homeassistant.components.media_player import BrowseMedia, MediaPlayerEntity
-from homeassistant.components.media_player.browse_media import (
+from homeassistant.components.media_player import (
+    ATTR_MEDIA_ANNOUNCE,
+    ATTR_MEDIA_ENQUEUE,
+    BrowseMedia,
+    MediaPlayerEnqueue,
+    MediaPlayerEntity,
+    MediaPlayerEntityFeature,
+    MediaPlayerState,
+    MediaType,
     async_process_play_media_url,
 )
-from homeassistant.components.media_player.const import MEDIA_TYPE_MUSIC
-from homeassistant.config_entries import ConfigEntry
-from homeassistant.const import (
-    CONF_HOST,
-    CONF_PASSWORD,
-    CONF_PORT,
-    STATE_IDLE,
-    STATE_OFF,
-    STATE_ON,
-    STATE_PAUSED,
-    STATE_PLAYING,
+from homeassistant.components.spotify import (
+    async_browse_media as spotify_async_browse_media,
+    is_spotify_media_type,
+    resolve_spotify_media_type,
+    spotify_uri_from_media_browser_url,
 )
+from homeassistant.config_entries import ConfigEntry
+from homeassistant.const import CONF_HOST, CONF_PASSWORD, CONF_PORT
 from homeassistant.core import HomeAssistant, callback
 from homeassistant.helpers.aiohttp_client import async_get_clientsession
 from homeassistant.helpers.dispatcher import (
@@ -35,6 +39,12 @@ from homeassistant.helpers.dispatcher import (
 from homeassistant.helpers.entity_platform import AddEntitiesCallback
 from homeassistant.util.dt import utcnow
 
+from .browse_media import (
+    convert_to_owntone_uri,
+    get_owntone_content,
+    is_owntone_media_content_id,
+    library,
+)
 from .const import (
     CALLBACK_TIMEOUT,
     CAN_PLAY_TYPE,
@@ -171,7 +181,7 @@ class ForkedDaapdZone(MediaPlayerEntity):
 
     async def async_toggle(self) -> None:
         """Toggle the power on the zone."""
-        if self.state == STATE_OFF:
+        if self.state == MediaPlayerState.OFF:
             await self.async_turn_on()
         else:
             await self.async_turn_off()
@@ -195,11 +205,11 @@ class ForkedDaapdZone(MediaPlayerEntity):
         return f"{FD_NAME} output ({self._output['name']})"
 
     @property
-    def state(self) -> str:
+    def state(self) -> MediaPlayerState:
         """State of the zone."""
         if self._output["selected"]:
-            return STATE_ON
-        return STATE_OFF
+            return MediaPlayerState.ON
+        return MediaPlayerState.OFF
 
     @property
     def volume_level(self):
@@ -227,7 +237,7 @@ class ForkedDaapdZone(MediaPlayerEntity):
         await self._api.set_volume(volume=volume * 100, output_id=self._output_id)
 
     @property
-    def supported_features(self):
+    def supported_features(self) -> MediaPlayerEntityFeature:
         """Flag media player features that are supported."""
         return SUPPORTED_FEATURES_ZONE
 
@@ -241,7 +251,8 @@ class ForkedDaapdMaster(MediaPlayerEntity):
         self, clientsession, api, ip_address, api_port, api_password, config_entry
     ):
         """Initialize the ForkedDaapd Master Device."""
-        self._api = api
+        # Leave the api public so the browse media helpers can use it
+        self.api = api
         self._player = STARTUP_DATA[
             "player"
         ]  # _player, _outputs, and _queue are loaded straight from api
@@ -355,11 +366,8 @@ class ForkedDaapdMaster(MediaPlayerEntity):
     @callback
     def _update_queue(self, queue, event):
         self._queue = queue
-        if (
-            self._tts_requested
-            and self._queue["count"] == 1
-            and self._queue["items"][0]["uri"].find("tts_proxy") != -1
-        ):
+        if self._tts_requested:
+            # Assume the change was due to the request
             self._tts_requested = False
             self._tts_queued = True
 
@@ -422,20 +430,22 @@ class ForkedDaapdMaster(MediaPlayerEntity):
     async def async_turn_on(self) -> None:
         """Restore the last on outputs state."""
         # restore state
-        await self._api.set_volume(volume=self._last_volume * 100)
+        await self.api.set_volume(volume=self._last_volume * 100)
         if self._last_outputs:
-            futures = []
+            futures: list[asyncio.Task[int]] = []
             for output in self._last_outputs:
                 futures.append(
-                    self._api.change_output(
-                        output["id"],
-                        selected=output["selected"],
-                        volume=output["volume"],
+                    asyncio.create_task(
+                        self.api.change_output(
+                            output["id"],
+                            selected=output["selected"],
+                            volume=output["volume"],
+                        )
                     )
                 )
             await asyncio.wait(futures)
         else:  # enable all outputs
-            await self._api.set_enabled_outputs(
+            await self.api.set_enabled_outputs(
                 [output["id"] for output in self._outputs]
             )
 
@@ -444,7 +454,7 @@ class ForkedDaapdMaster(MediaPlayerEntity):
         await self.async_media_pause()
         self._last_outputs = self._outputs
         if any(output["selected"] for output in self._outputs):
-            await self._api.set_enabled_outputs([])
+            await self.api.set_enabled_outputs([])
 
     async def async_toggle(self) -> None:
         """Toggle the power on the device.
@@ -452,7 +462,7 @@ class ForkedDaapdMaster(MediaPlayerEntity):
         Default media player component method counts idle as off.
         We consider idle to be on but just not playing.
         """
-        if self.state == STATE_OFF:
+        if self.state == MediaPlayerState.OFF:
             await self.async_turn_on()
         else:
             await self.async_turn_off()
@@ -463,16 +473,17 @@ class ForkedDaapdMaster(MediaPlayerEntity):
         return f"{FD_NAME} server"
 
     @property
-    def state(self):
+    def state(self) -> MediaPlayerState | None:
         """State of the player."""
         if self._player["state"] == "play":
-            return STATE_PLAYING
+            return MediaPlayerState.PLAYING
         if self._player["state"] == "pause":
-            return STATE_PAUSED
+            return MediaPlayerState.PAUSED
         if not any(output["selected"] for output in self._outputs):
-            return STATE_OFF
+            return MediaPlayerState.OFF
         if self._player["state"] == "stop":  # this should catch all remaining cases
-            return STATE_IDLE
+            return MediaPlayerState.IDLE
+        return None
 
     @property
     def volume_level(self):
@@ -548,7 +559,7 @@ class ForkedDaapdMaster(MediaPlayerEntity):
         return self._player["shuffle"]
 
     @property
-    def supported_features(self):
+    def supported_features(self) -> MediaPlayerEntityFeature:
         """Flag media player features that are supported."""
         return SUPPORTED_FEATURES
 
@@ -571,32 +582,32 @@ class ForkedDaapdMaster(MediaPlayerEntity):
             target_volume = 0
         else:
             target_volume = self._last_volume  # restore volume level
-        await self._api.set_volume(volume=target_volume * 100)
+        await self.api.set_volume(volume=target_volume * 100)
 
     async def async_set_volume_level(self, volume: float) -> None:
         """Set volume - input range [0,1]."""
-        await self._api.set_volume(volume=volume * 100)
+        await self.api.set_volume(volume=volume * 100)
 
     async def async_media_play(self) -> None:
         """Start playback."""
         if self._use_pipe_control():
             await self._pipe_call(self._use_pipe_control(), "async_media_play")
         else:
-            await self._api.start_playback()
+            await self.api.start_playback()
 
     async def async_media_pause(self) -> None:
         """Pause playback."""
         if self._use_pipe_control():
             await self._pipe_call(self._use_pipe_control(), "async_media_pause")
         else:
-            await self._api.pause_playback()
+            await self.api.pause_playback()
 
     async def async_media_stop(self) -> None:
         """Stop playback."""
         if self._use_pipe_control():
             await self._pipe_call(self._use_pipe_control(), "async_media_stop")
         else:
-            await self._api.stop_playback()
+            await self.api.stop_playback()
 
     async def async_media_previous_track(self) -> None:
         """Skip to previous track."""
@@ -605,32 +616,32 @@ class ForkedDaapdMaster(MediaPlayerEntity):
                 self._use_pipe_control(), "async_media_previous_track"
             )
         else:
-            await self._api.previous_track()
+            await self.api.previous_track()
 
     async def async_media_next_track(self) -> None:
         """Skip to next track."""
         if self._use_pipe_control():
             await self._pipe_call(self._use_pipe_control(), "async_media_next_track")
         else:
-            await self._api.next_track()
+            await self.api.next_track()
 
     async def async_media_seek(self, position: float) -> None:
         """Seek to position."""
-        await self._api.seek(position_ms=position * 1000)
+        await self.api.seek(position_ms=position * 1000)
 
     async def async_clear_playlist(self) -> None:
         """Clear playlist."""
-        await self._api.clear_queue()
+        await self.api.clear_queue()
 
     async def async_set_shuffle(self, shuffle: bool) -> None:
         """Enable/disable shuffle mode."""
-        await self._api.shuffle(shuffle)
+        await self.api.shuffle(shuffle)
 
     @property
     def media_image_url(self):
         """Image url of current playing media."""
         if url := self._track_info.get("artwork_url"):
-            url = self._api.full_url(url)
+            url = self.api.full_url(url)
         return url
 
     async def _save_and_set_tts_volumes(self):
@@ -638,11 +649,11 @@ class ForkedDaapdMaster(MediaPlayerEntity):
             self._last_volume = self.volume_level
         self._last_outputs = self._outputs
         if self._outputs:
-            await self._api.set_volume(volume=self._tts_volume * 100)
+            await self.api.set_volume(volume=self._tts_volume * 100)
             futures = []
             for output in self._outputs:
                 futures.append(
-                    self._api.change_output(
+                    self.api.change_output(
                         output["id"], selected=True, volume=self._tts_volume * 100
                     )
                 )
@@ -653,90 +664,139 @@ class ForkedDaapdMaster(MediaPlayerEntity):
         self._pause_requested = True
         await self.async_media_pause()
         try:
-            await asyncio.wait_for(
-                self._paused_event.wait(), timeout=CALLBACK_TIMEOUT
-            )  # wait for paused
+            async with async_timeout.timeout(CALLBACK_TIMEOUT):
+                await self._paused_event.wait()  # wait for paused
         except asyncio.TimeoutError:
             self._pause_requested = False
         self._paused_event.clear()
 
     async def async_play_media(
-        self, media_type: str, media_id: str, **kwargs: Any
+        self, media_type: MediaType | str, media_id: str, **kwargs: Any
     ) -> None:
         """Play a URI."""
+
+        # Preprocess media_ids
         if media_source.is_media_source_id(media_id):
-            media_type = MEDIA_TYPE_MUSIC
+            media_type = MediaType.MUSIC
             play_item = await media_source.async_resolve_media(
                 self.hass, media_id, self.entity_id
             )
             media_id = play_item.url
+        elif is_owntone_media_content_id(media_id):
+            media_id = convert_to_owntone_uri(media_id)
+        elif is_spotify_media_type(media_type):
+            media_type = resolve_spotify_media_type(media_type)
+            media_id = spotify_uri_from_media_browser_url(media_id)
 
-        if media_type == MEDIA_TYPE_MUSIC:
+        if media_type not in CAN_PLAY_TYPE:
+            _LOGGER.warning("Media type '%s' not supported", media_type)
+            return
+
+        if media_type == MediaType.MUSIC:
             media_id = async_process_play_media_url(self.hass, media_id)
+        elif media_type not in CAN_PLAY_TYPE:
+            _LOGGER.warning("Media type '%s' not supported", media_type)
+            return
 
-            saved_state = self.state  # save play state
-            saved_mute = self.is_volume_muted
-            sleep_future = asyncio.create_task(
-                asyncio.sleep(self._tts_pause_time)
-            )  # start timing now, but not exact because of fd buffer + tts latency
-            await self._pause_and_wait_for_callback()
-            await self._save_and_set_tts_volumes()
-            # save position
-            saved_song_position = self._player["item_progress_ms"]
-            saved_queue = (
-                self._queue if self._queue["count"] > 0 else None
-            )  # stash queue
-            if saved_queue:
-                saved_queue_position = next(
-                    i
-                    for i, item in enumerate(saved_queue["items"])
-                    if item["id"] == self._player["item_id"]
-                )
-            self._tts_requested = True
-            await sleep_future
-            await self._api.add_to_queue(uris=media_id, playback="start", clear=True)
-            try:
-                await asyncio.wait_for(
-                    self._tts_playing_event.wait(), timeout=TTS_TIMEOUT
-                )
-                # we have started TTS, now wait for completion
-                await asyncio.sleep(
-                    self._queue["items"][0]["length_ms"]
-                    / 1000  # player may not have updated yet so grab length from queue
-                    + self._tts_pause_time
-                )
-            except asyncio.TimeoutError:
-                self._tts_requested = False
-                _LOGGER.warning("TTS request timed out")
-            self._tts_playing_event.clear()
-            # TTS done, return to normal
-            await self.async_turn_on()  # restore outputs and volumes
-            if saved_mute:  # mute if we were muted
-                await self.async_mute_volume(True)
-            if self._use_pipe_control():  # resume pipe
-                await self._api.add_to_queue(
-                    uris=self._sources_uris[self._source], clear=True
-                )
-                if saved_state == STATE_PLAYING:
-                    await self.async_media_play()
-            else:  # restore stashed queue
-                if saved_queue:
-                    uris = ""
-                    for item in saved_queue["items"]:
-                        uris += item["uri"] + ","
-                    await self._api.add_to_queue(
-                        uris=uris,
-                        playback="start",
-                        playback_from_position=saved_queue_position,
-                        clear=True,
-                    )
-                    await self._api.seek(position_ms=saved_song_position)
-                    if saved_state == STATE_PAUSED:
-                        await self.async_media_pause()
-                    elif saved_state != STATE_PLAYING:
-                        await self.async_media_stop()
-        else:
-            _LOGGER.debug("Media type '%s' not supported", media_type)
+        if kwargs.get(ATTR_MEDIA_ANNOUNCE):
+            return await self._async_announce(media_id)
+
+        # if kwargs[ATTR_MEDIA_ENQUEUE] is None, we assume MediaPlayerEnqueue.REPLACE
+        # if kwargs[ATTR_MEDIA_ENQUEUE] is True, we assume MediaPlayerEnqueue.ADD
+        # kwargs[ATTR_MEDIA_ENQUEUE] is assumed to never be False
+        # See https://github.com/home-assistant/architecture/issues/765
+        enqueue: bool | MediaPlayerEnqueue = kwargs.get(
+            ATTR_MEDIA_ENQUEUE, MediaPlayerEnqueue.REPLACE
+        )
+        if enqueue in {True, MediaPlayerEnqueue.ADD, MediaPlayerEnqueue.REPLACE}:
+            return await self.api.add_to_queue(
+                uris=media_id,
+                playback="start",
+                clear=enqueue == MediaPlayerEnqueue.REPLACE,
+            )
+
+        current_position = next(
+            (
+                item["position"]
+                for item in self._queue["items"]
+                if item["id"] == self._player["item_id"]
+            ),
+            0,
+        )
+        if enqueue == MediaPlayerEnqueue.NEXT:
+            return await self.api.add_to_queue(
+                uris=media_id,
+                playback="start",
+                position=current_position + 1,
+            )
+        # enqueue == MediaPlayerEnqueue.PLAY
+        return await self.api.add_to_queue(
+            uris=media_id,
+            playback="start",
+            position=current_position,
+            playback_from_position=current_position,
+        )
+
+    async def _async_announce(self, media_id: str) -> None:
+        """Play a URI."""
+        saved_state = self.state  # save play state
+        saved_mute = self.is_volume_muted
+        sleep_future = asyncio.create_task(
+            asyncio.sleep(self._tts_pause_time)
+        )  # start timing now, but not exact because of fd buffer + tts latency
+        await self._pause_and_wait_for_callback()
+        await self._save_and_set_tts_volumes()
+        # save position
+        saved_song_position = self._player["item_progress_ms"]
+        saved_queue = self._queue if self._queue["count"] > 0 else None  # stash queue
+        if saved_queue:
+            saved_queue_position = next(
+                i
+                for i, item in enumerate(saved_queue["items"])
+                if item["id"] == self._player["item_id"]
+            )
+        self._tts_requested = True
+        await sleep_future
+        await self.api.add_to_queue(uris=media_id, playback="start", clear=True)
+        try:
+            async with async_timeout.timeout(TTS_TIMEOUT):
+                await self._tts_playing_event.wait()
+            # we have started TTS, now wait for completion
+        except asyncio.TimeoutError:
+            self._tts_requested = False
+            _LOGGER.warning("TTS request timed out")
+        await asyncio.sleep(
+            self._queue["items"][0]["length_ms"]
+            / 1000  # player may not have updated yet so grab length from queue
+            + self._tts_pause_time
+        )
+        self._tts_playing_event.clear()
+        # TTS done, return to normal
+        await self.async_turn_on()  # restore outputs and volumes
+        if saved_mute:  # mute if we were muted
+            await self.async_mute_volume(True)
+        if self._use_pipe_control():  # resume pipe
+            await self.api.add_to_queue(
+                uris=self._sources_uris[self._source], clear=True
+            )
+            if saved_state == MediaPlayerState.PLAYING:
+                await self.async_media_play()
+            return
+        if not saved_queue:
+            return
+        # Restore stashed queue
+        await self.api.add_to_queue(
+            uris=",".join(item["uri"] for item in saved_queue["items"]),
+            playback="start",
+            playback_from_position=saved_queue_position,
+            clear=True,
+        )
+        await self.api.seek(position_ms=saved_song_position)
+        if saved_state == MediaPlayerState.PAUSED:
+            await self.async_media_pause()
+            return
+        if saved_state != MediaPlayerState.PLAYING:
+            await self.async_media_stop()
 
     async def async_select_source(self, source: str) -> None:
         """Change source.
@@ -753,9 +813,9 @@ class ForkedDaapdMaster(MediaPlayerEntity):
         if not self._use_pipe_control():  # playlist or clear ends up at default
             self._source = SOURCE_NAME_DEFAULT
         if self._sources_uris.get(source):  # load uris for pipes or playlists
-            await self._api.add_to_queue(uris=self._sources_uris[source], clear=True)
+            await self.api.add_to_queue(uris=self._sources_uris[source], clear=True)
         elif source == SOURCE_NAME_CLEAR:  # clear playlist
-            await self._api.clear_queue()
+            await self.api.clear_queue()
         self.async_write_ha_state()
 
     def _use_pipe_control(self):
@@ -778,11 +838,65 @@ class ForkedDaapdMaster(MediaPlayerEntity):
         media_content_id: str | None = None,
     ) -> BrowseMedia:
         """Implement the websocket media browsing helper."""
-        return await media_source.async_browse_media(
-            self.hass,
-            media_content_id,
-            content_filter=lambda bm: bm.media_content_type in CAN_PLAY_TYPE,
-        )
+        if media_content_id is None or media_source.is_media_source_id(
+            media_content_id
+        ):
+            ms_result = await media_source.async_browse_media(
+                self.hass,
+                media_content_id,
+                content_filter=lambda bm: bm.media_content_type in CAN_PLAY_TYPE,
+            )
+            if media_content_type is not None:
+                return ms_result
+            other_sources: list[BrowseMedia] = (
+                list(ms_result.children) if ms_result.children else []
+            )
+        if "spotify" in self.hass.config.components and (
+            media_content_type is None or is_spotify_media_type(media_content_type)
+        ):
+            spotify_result = await spotify_async_browse_media(
+                self.hass, media_content_type, media_content_id
+            )
+            if media_content_type is not None:
+                return spotify_result
+            if spotify_result.children:
+                other_sources += spotify_result.children
+
+        if media_content_id is None or media_content_type is None:
+            # This is the base level, so we combine our library with the other sources
+            return library(other_sources)
+
+        # media_content_type should only be None if media_content_id is None
+        return await get_owntone_content(self, media_content_id)
+
+    async def async_get_browse_image(
+        self,
+        media_content_type: str,
+        media_content_id: str,
+        media_image_id: str | None = None,
+    ) -> tuple[bytes | None, str | None]:
+        """Fetch image for media browser."""
+
+        if media_content_type not in {
+            MediaType.TRACK,
+            MediaType.ALBUM,
+            MediaType.ARTIST,
+        }:
+            return None, None
+        owntone_uri = convert_to_owntone_uri(media_content_id)
+        item_id_str = owntone_uri.rsplit(":", maxsplit=1)[-1]
+        if media_content_type == MediaType.TRACK:
+            result = await self.api.get_track(int(item_id_str))
+        elif media_content_type == MediaType.ALBUM:
+            if result := await self.api.get_albums():
+                result = next(
+                    (item for item in result if item["id"] == item_id_str), None
+                )
+        elif result := await self.api.get_artists():
+            result = next((item for item in result if item["id"] == item_id_str), None)
+        if url := result.get("artwork_url"):
+            return await self._async_fetch_image(self.api.full_url(url))
+        return None, None
 
 
 class ForkedDaapdUpdater:
@@ -812,7 +926,8 @@ class ForkedDaapdUpdater:
         else:
             _LOGGER.error("Invalid websocket port")
 
-    def _disconnected_callback(self):
+    async def _disconnected_callback(self):
+        """Send update signals when the websocket gets disconnected."""
         async_dispatcher_send(
             self.hass, SIGNAL_UPDATE_MASTER.format(self._entry_id), False
         )
