@@ -6,13 +6,15 @@ from homeassistant.components.hassio import get_os_info
 from homeassistant.core import HomeAssistant, callback
 from homeassistant.exceptions import HomeAssistantError
 
+from .const import DOMAIN
+
 BOARD_NAME = "Home Assistant Yellow"
 MANUFACTURER = "homeassistant"
 MODEL = "yellow"
 
 
 @callback
-def async_info(hass: HomeAssistant) -> HardwareInfo:
+def async_info(hass: HomeAssistant) -> list[HardwareInfo]:
     """Return board info."""
     if (os_info := get_os_info(hass)) is None:
         raise HomeAssistantError
@@ -22,13 +24,21 @@ def async_info(hass: HomeAssistant) -> HardwareInfo:
     if not board == "yellow":
         raise HomeAssistantError
 
-    return HardwareInfo(
-        board=BoardInfo(
-            hassio_board_id=board,
-            manufacturer=MANUFACTURER,
-            model=MODEL,
-            revision=None,
-        ),
-        name=BOARD_NAME,
-        url=None,
-    )
+    config_entries = [
+        entry.entry_id for entry in hass.config_entries.async_entries(DOMAIN)
+    ]
+
+    return [
+        HardwareInfo(
+            board=BoardInfo(
+                hassio_board_id=board,
+                manufacturer=MANUFACTURER,
+                model=MODEL,
+                revision=None,
+            ),
+            config_entries=config_entries,
+            dongle=None,
+            name=BOARD_NAME,
+            url=None,
+        )
+    ]
