@@ -7,8 +7,7 @@ from typing import Any
 from pizone import Controller, Zone
 import voluptuous as vol
 
-from homeassistant.components.climate import ClimateEntity
-from homeassistant.components.climate.const import (
+from homeassistant.components.climate import (
     FAN_AUTO,
     FAN_HIGH,
     FAN_LOW,
@@ -16,6 +15,7 @@ from homeassistant.components.climate.const import (
     FAN_TOP,
     PRESET_ECO,
     PRESET_NONE,
+    ClimateEntity,
     ClimateEntityFeature,
     HVACMode,
 )
@@ -25,7 +25,7 @@ from homeassistant.const import (
     CONF_EXCLUDE,
     PRECISION_HALVES,
     PRECISION_TENTHS,
-    TEMP_CELSIUS,
+    UnitOfTemperature,
 )
 from homeassistant.core import HomeAssistant, callback
 from homeassistant.helpers import entity_platform
@@ -129,7 +129,7 @@ class ControllerDevice(ClimateEntity):
 
     _attr_precision = PRECISION_TENTHS
     _attr_should_poll = False
-    _attr_temperature_unit = TEMP_CELSIUS
+    _attr_temperature_unit = UnitOfTemperature.CELSIUS
 
     def __init__(self, controller: Controller) -> None:
         """Initialise ControllerDevice."""
@@ -173,6 +173,7 @@ class ControllerDevice(ClimateEntity):
 
     async def async_added_to_hass(self) -> None:
         """Call on adding to hass."""
+
         # Register for connect/disconnect/update events
         @callback
         def controller_disconnected(ctrl: Controller, ex: Exception) -> None:
@@ -290,12 +291,12 @@ class ControllerDevice(ClimateEntity):
             return HVACMode.OFF
         if (mode := self._controller.mode) == Controller.Mode.FREE_AIR:
             return HVACMode.FAN_ONLY
-        for (key, value) in self._state_to_pizone.items():
+        for key, value in self._state_to_pizone.items():
             if value == mode:
                 return key
         assert False, "Should be unreachable"
 
-    @property  # type: ignore[misc]
+    @property
     @_return_on_connection_error([])
     def hvac_modes(self) -> list[HVACMode]:
         """Return the list of available operation modes."""
@@ -303,13 +304,13 @@ class ControllerDevice(ClimateEntity):
             return [HVACMode.OFF, HVACMode.FAN_ONLY]
         return [HVACMode.OFF, *self._state_to_pizone]
 
-    @property  # type: ignore[misc]
+    @property
     @_return_on_connection_error(PRESET_NONE)
     def preset_mode(self):
         """Eco mode is external air."""
         return PRESET_ECO if self._controller.free_air else PRESET_NONE
 
-    @property  # type: ignore[misc]
+    @property
     @_return_on_connection_error([PRESET_NONE])
     def preset_modes(self):
         """Available preset modes, normal or eco."""
@@ -317,7 +318,7 @@ class ControllerDevice(ClimateEntity):
             return [PRESET_NONE, PRESET_ECO]
         return [PRESET_NONE]
 
-    @property  # type: ignore[misc]
+    @property
     @_return_on_connection_error()
     def current_temperature(self) -> float | None:
         """Return the current temperature."""
@@ -347,7 +348,7 @@ class ControllerDevice(ClimateEntity):
             return None
         return zone.target_temperature
 
-    @property  # type: ignore[misc]
+    @property
     @_return_on_connection_error()
     def target_temperature(self) -> float | None:
         """Return the temperature we try to reach (either from control zone or master unit)."""
@@ -375,13 +376,13 @@ class ControllerDevice(ClimateEntity):
         """Return the list of available fan modes."""
         return list(self._fan_to_pizone)
 
-    @property  # type: ignore[misc]
+    @property
     @_return_on_connection_error(0.0)
     def min_temp(self) -> float:
         """Return the minimum temperature."""
         return self._controller.temp_min
 
-    @property  # type: ignore[misc]
+    @property
     @_return_on_connection_error(50.0)
     def max_temp(self) -> float:
         """Return the maximum temperature."""
@@ -437,7 +438,7 @@ class ZoneDevice(ClimateEntity):
 
     _attr_precision = PRECISION_TENTHS
     _attr_should_poll = False
-    _attr_temperature_unit = TEMP_CELSIUS
+    _attr_temperature_unit = UnitOfTemperature.CELSIUS
 
     def __init__(self, controller: ControllerDevice, zone: Zone) -> None:
         """Initialise ZoneDevice."""
@@ -445,7 +446,6 @@ class ZoneDevice(ClimateEntity):
         self._zone = zone
         self._name = zone.name.title()
 
-        self._attr_supported_features = 0
         if zone.type != Zone.Type.AUTO:
             self._state_to_pizone = {
                 HVACMode.OFF: Zone.Mode.CLOSE,
@@ -516,9 +516,9 @@ class ZoneDevice(ClimateEntity):
         """Return the name of the entity."""
         return self._name
 
-    @property  # type: ignore[misc]
+    @property
     @_return_on_connection_error(0)
-    def supported_features(self) -> int:
+    def supported_features(self) -> ClimateEntityFeature:
         """Return the list of supported features."""
         if self._zone.mode == Zone.Mode.AUTO:
             return self._attr_supported_features
@@ -528,7 +528,7 @@ class ZoneDevice(ClimateEntity):
     def hvac_mode(self) -> HVACMode | None:
         """Return current operation ie. heat, cool, idle."""
         mode = self._zone.mode
-        for (key, value) in self._state_to_pizone.items():
+        for key, value in self._state_to_pizone.items():
             if value == mode:
                 return key
         return None
