@@ -1,8 +1,6 @@
 """Support for Kegtron sensors."""
 from __future__ import annotations
 
-from typing import Optional, Union
-
 from kegtron_ble import (
     SensorDeviceClass as KegtronSensorDeviceClass,
     SensorUpdate,
@@ -22,7 +20,7 @@ from homeassistant.components.sensor import (
     SensorEntityDescription,
     SensorStateClass,
 )
-from homeassistant.const import SIGNAL_STRENGTH_DECIBELS_MILLIWATT, VOLUME_LITERS
+from homeassistant.const import SIGNAL_STRENGTH_DECIBELS_MILLIWATT, UnitOfVolume
 from homeassistant.core import HomeAssistant
 from homeassistant.helpers.entity import EntityCategory
 from homeassistant.helpers.entity_platform import AddEntitiesCallback
@@ -39,7 +37,7 @@ SENSOR_DESCRIPTIONS = {
     KegtronSensorDeviceClass.KEG_SIZE: SensorEntityDescription(
         key=KegtronSensorDeviceClass.KEG_SIZE,
         icon="mdi:keg",
-        native_unit_of_measurement=VOLUME_LITERS,
+        native_unit_of_measurement=UnitOfVolume.LITERS,
         device_class=SensorDeviceClass.VOLUME,
         state_class=SensorStateClass.MEASUREMENT,
     ),
@@ -50,14 +48,14 @@ SENSOR_DESCRIPTIONS = {
     KegtronSensorDeviceClass.VOLUME_START: SensorEntityDescription(
         key=KegtronSensorDeviceClass.VOLUME_START,
         icon="mdi:keg",
-        native_unit_of_measurement=VOLUME_LITERS,
+        native_unit_of_measurement=UnitOfVolume.LITERS,
         device_class=SensorDeviceClass.VOLUME,
         state_class=SensorStateClass.MEASUREMENT,
     ),
     KegtronSensorDeviceClass.VOLUME_DISPENSED: SensorEntityDescription(
         key=KegtronSensorDeviceClass.VOLUME_DISPENSED,
         icon="mdi:keg",
-        native_unit_of_measurement=VOLUME_LITERS,
+        native_unit_of_measurement=UnitOfVolume.LITERS,
         device_class=SensorDeviceClass.VOLUME,
         state_class=SensorStateClass.TOTAL,
     ),
@@ -126,9 +124,7 @@ async def async_setup_entry(
 
 
 class KegtronBluetoothSensorEntity(
-    PassiveBluetoothProcessorEntity[
-        PassiveBluetoothDataProcessor[Optional[Union[float, int]]]
-    ],
+    PassiveBluetoothProcessorEntity[PassiveBluetoothDataProcessor[float | int | None]],
     SensorEntity,
 ):
     """Representation of a Kegtron sensor."""
