@@ -4,7 +4,7 @@ from __future__ import annotations
 import logging
 from typing import Any, Final, cast
 
-from aiolookin import Climate, MeteoSensor
+from aiolookin import Climate, MeteoSensor, Remote
 from aiolookin.models import UDPCommandType, UDPEvent
 
 from homeassistant.components.climate import (
@@ -23,8 +23,8 @@ from homeassistant.config_entries import ConfigEntry
 from homeassistant.const import (
     ATTR_TEMPERATURE,
     PRECISION_WHOLE,
-    TEMP_CELSIUS,
     Platform,
+    UnitOfTemperature,
 )
 from homeassistant.core import HomeAssistant, callback
 from homeassistant.helpers.entity_platform import AddEntitiesCallback
@@ -75,7 +75,7 @@ async def async_setup_entry(
             continue
         uuid = remote["UUID"]
         coordinator = lookin_data.device_coordinators[uuid]
-        device: Climate = coordinator.data
+        device = cast(Climate, coordinator.data)
         entities.append(
             ConditionerEntity(
                 uuid=uuid,
@@ -92,7 +92,7 @@ class ConditionerEntity(LookinCoordinatorEntity, ClimateEntity):
     """An aircon or heat pump."""
 
     _attr_current_humidity: float | None = None  # type: ignore[assignment]
-    _attr_temperature_unit = TEMP_CELSIUS
+    _attr_temperature_unit = UnitOfTemperature.CELSIUS
     _attr_supported_features = (
         ClimateEntityFeature.TARGET_TEMPERATURE
         | ClimateEntityFeature.FAN_MODE
@@ -110,7 +110,7 @@ class ConditionerEntity(LookinCoordinatorEntity, ClimateEntity):
         uuid: str,
         device: Climate,
         lookin_data: LookinData,
-        coordinator: LookinDataUpdateCoordinator,
+        coordinator: LookinDataUpdateCoordinator[Remote],
     ) -> None:
         """Init the ConditionerEntity."""
         super().__init__(coordinator, uuid, device, lookin_data)
@@ -146,13 +146,18 @@ class ConditionerEntity(LookinCoordinatorEntity, ClimateEntity):
             # or cool otherwise we set auto since we don't have a way to make
             # an educated guess.
             #
-            meteo_data: MeteoSensor = self._meteo_coordinator.data
-            if not (current_temp := meteo_data.temperature):
-                self._climate.hvac_mode = lookin_index.index(HVACMode.AUTO)
-            elif current_temp >= self._climate.temp_celsius:
-                self._climate.hvac_mode = lookin_index.index(HVACMode.COOL)
+
+            if self._meteo_coordinator:
+                meteo_data: MeteoSensor = self._meteo_coordinator.data
+                if not (current_temp := meteo_data.temperature):
+                    self._climate.hvac_mode = lookin_index.index(HVACMode.AUTO)
+                elif current_temp >= self._climate.temp_celsius:
+                    self._climate.hvac_mode = lookin_index.index(HVACMode.COOL)
+                else:
+                    self._climate.hvac_mode = lookin_index.index(HVACMode.HEAT)
             else:
-                self._climate.hvac_mode = lookin_index.index(HVACMode.HEAT)
+                self._climate.hvac_mode = lookin_index.index(HVACMode.AUTO)
+
         await self._async_update_conditioner()
 
     async def async_set_fan_mode(self, fan_mode: str) -> None:
@@ -172,14 +177,20 @@ class ConditionerEntity(LookinCoordinatorEntity, ClimateEntity):
     async def _async_update_conditioner(self) -> None:
         """Update the conditioner state from the climate data."""
         self.coordinator.async_set_updated_data(self._climate)
-        await self._lookin_protocol.update_conditioner(climate=self._climate)
+        await self._lookin_protocol.update_conditioner(
+            uuid=self._attr_unique_id, status=self._climate.to_status
+        )
 
     def _async_update_from_data(self) -> None:
         """Update attrs from data."""
-        meteo_data: MeteoSensor = self._meteo_coordinator.data
+        if self._meteo_coordinator:
+            temperature = self._meteo_coordinator.data.temperature
+            humidity = int(self._meteo_coordinator.data.humidity)
+        else:
+            temperature = humidity = None
 
-        self._attr_current_temperature = meteo_data.temperature
-        self._attr_current_humidity = int(meteo_data.humidity)
+        self._attr_current_temperature = temperature
+        self._attr_current_humidity = humidity
         self._attr_target_temperature = self._climate.temp_celsius
         self._attr_fan_mode = LOOKIN_FAN_MODE_IDX_TO_HASS[self._climate.fan_mode]
         self._attr_swing_mode = LOOKIN_SWING_MODE_IDX_TO_HASS[self._climate.swing_mode]
