@@ -5,16 +5,18 @@ from abc import abstractmethod
 from collections.abc import Callable
 from dataclasses import dataclass
 import logging
-from typing import TYPE_CHECKING, Any
+from typing import TYPE_CHECKING, Any, cast
 
 from matter_server.common.models.device_type_instance import MatterDeviceTypeInstance
 from matter_server.common.models.events import EventType
 from matter_server.common.models.node_device import AbstractMatterNodeDevice
+from matter_server.common.models.server_information import ServerInfo
 
 from homeassistant.core import callback
 from homeassistant.helpers.entity import DeviceInfo, Entity, EntityDescription
 
-from .const import DOMAIN
+from .const import DOMAIN, ID_TYPE_DEVICE_ID
+from .helpers import get_device_id, get_operational_instance_id
 
 if TYPE_CHECKING:
     from matter_server.client import MatterClient
@@ -55,24 +57,21 @@ class MatterEntity(Entity):
         self._node_device = node_device
         self._device_type_instance = device_type_instance
         self.entity_description = entity_description
-        node = device_type_instance.node
         self._unsubscribes: list[Callable] = []
         # for fast lookups we create a mapping to the attribute paths
-        self._attributes_map: dict[type, str] = {}
-        server_info = matter_client.server_info
         # The server info is set when the client connects to the server.
-        assert server_info is not None
+        self._attributes_map: dict[type, str] = {}
+        server_info = cast(ServerInfo, self.matter_client.server_info)
+        # create unique_id based on "Operational Instance Name" and endpoint/device type
         self._attr_unique_id = (
-            f"{server_info.compressed_fabric_id}-"
-            f"{node.unique_id}-"
+            f"{get_operational_instance_id(server_info, self._node_device.node())}-"
             f"{device_type_instance.endpoint}-"
             f"{device_type_instance.device_type.device_type}"
         )
-
-    @property
-    def device_info(self) -> DeviceInfo | None:
-        """Return device info for device registry."""
-        return {"identifiers": {(DOMAIN, self._node_device.device_info().uniqueID)}}
+        node_device_id = get_device_id(server_info, node_device)
+        self._attr_device_info = DeviceInfo(
+            identifiers={(DOMAIN, f"{ID_TYPE_DEVICE_ID}_{node_device_id}")}
+        )
 
     async def async_added_to_hass(self) -> None:
         """Handle being added to Home Assistant."""
@@ -115,7 +114,7 @@ class MatterEntity(Entity):
 
     @callback
     def get_matter_attribute(self, attribute: type) -> MatterAttribute | None:
-        """Lookup MatterAttribute instance on device instance by providing the attribute class."""
+        """Lookup MatterAttribute on device by providing the attribute class."""
         return next(
             (
                 x
