@@ -42,7 +42,10 @@ ABBREVIATIONS = {
     "cmd_tpl": "command_template",
     "cod_arm_req": "code_arm_required",
     "cod_dis_req": "code_disarm_required",
+    "cod_form": "code_format",
     "cod_trig_req": "code_trigger_required",
+    "curr_hum_t": "current_humidity_topic",
+    "curr_hum_tpl": "current_humidity_template",
     "curr_temp_t": "current_temperature_topic",
     "curr_temp_tpl": "current_temperature_template",
     "dev": "device",
@@ -78,6 +81,7 @@ ABBREVIATIONS = {
     "hold_stat_tpl": "hold_state_template",
     "hold_stat_t": "hold_state_topic",
     "hs_cmd_t": "hs_command_topic",
+    "hs_cmd_tpl": "hs_command_template",
     "hs_stat_t": "hs_state_topic",
     "hs_val_tpl": "hs_value_template",
     "ic": "icon",
@@ -195,13 +199,16 @@ ABBREVIATIONS = {
     "stat_cla": "state_class",
     "stat_clsd": "state_closed",
     "stat_closing": "state_closing",
+    "stat_jam": "state_jammed",
     "stat_off": "state_off",
     "stat_on": "state_on",
     "stat_open": "state_open",
     "stat_opening": "state_opening",
     "stat_stopped": "state_stopped",
     "stat_locked": "state_locked",
+    "stat_locking": "state_locking",
     "stat_unlocked": "state_unlocked",
+    "stat_unlocking": "state_unlocking",
     "stat_t": "state_topic",
     "stat_tpl": "state_template",
     "stat_val_tpl": "state_value_template",
@@ -250,6 +257,7 @@ ABBREVIATIONS = {
     "whit_val_stat_t": "white_value_state_topic",
     "whit_val_tpl": "white_value_template",
     "xy_cmd_t": "xy_command_topic",
+    "xy_cmd_tpl": "xy_command_template",
     "xy_stat_t": "xy_state_topic",
     "xy_val_tpl": "xy_value_template",
     "l_ver_t": "latest_version_topic",
