@@ -17,10 +17,7 @@ from sqlalchemy.sql.expression import literal
 from sqlalchemy.sql.lambdas import StatementLambdaElement
 from sqlalchemy.sql.selectable import Subquery
 
-from homeassistant.components.websocket_api import (
-    COMPRESSED_STATE_LAST_UPDATED,
-    COMPRESSED_STATE_STATE,
-)
+from homeassistant.const import COMPRESSED_STATE_LAST_UPDATED, COMPRESSED_STATE_STATE
 from homeassistant.core import HomeAssistant, State, split_entity_id
 import homeassistant.util.dt as dt_util
 
@@ -29,10 +26,12 @@ from .db_schema import RecorderRuns, StateAttributes, States
 from .filters import Filters
 from .models import (
     LazyState,
+    LazyStatePreSchema31,
     process_datetime_to_timestamp,
     process_timestamp,
     process_timestamp_to_utc_isoformat,
     row_to_compressed_state,
+    row_to_compressed_state_pre_schema_31,
 )
 from .util import execute_stmt_lambda_element, session_scope
 
@@ -59,49 +58,84 @@ NEED_ATTRIBUTE_DOMAINS = {
     "water_heater",
 }
 
-BASE_STATES = [
+
+_BASE_STATES = [
+    States.entity_id,
+    States.state,
+    States.last_changed_ts,
+    States.last_updated_ts,
+]
+_BASE_STATES_NO_LAST_CHANGED = [
+    States.entity_id,
+    States.state,
+    literal(value=None).label("last_changed_ts"),
+    States.last_updated_ts,
+]
+_QUERY_STATE_NO_ATTR = [
+    *_BASE_STATES,
+    literal(value=None, type_=Text).label("attributes"),
+    literal(value=None, type_=Text).label("shared_attrs"),
+]
+_QUERY_STATE_NO_ATTR_NO_LAST_CHANGED = [
+    *_BASE_STATES_NO_LAST_CHANGED,
+    literal(value=None, type_=Text).label("attributes"),
+    literal(value=None, type_=Text).label("shared_attrs"),
+]
+_BASE_STATES_PRE_SCHEMA_31 = [
     States.entity_id,
     States.state,
     States.last_changed,
     States.last_updated,
 ]
-BASE_STATES_NO_LAST_CHANGED = [
+_BASE_STATES_NO_LAST_CHANGED_PRE_SCHEMA_31 = [
     States.entity_id,
     States.state,
     literal(value=None, type_=Text).label("last_changed"),
     States.last_updated,
 ]
-QUERY_STATE_NO_ATTR = [
-    *BASE_STATES,
+_QUERY_STATE_NO_ATTR_PRE_SCHEMA_31 = [
+    *_BASE_STATES_PRE_SCHEMA_31,
     literal(value=None, type_=Text).label("attributes"),
     literal(value=None, type_=Text).label("shared_attrs"),
 ]
-QUERY_STATE_NO_ATTR_NO_LAST_CHANGED = [
-    *BASE_STATES_NO_LAST_CHANGED,
+_QUERY_STATE_NO_ATTR_NO_LAST_CHANGED_PRE_SCHEMA_31 = [
+    *_BASE_STATES_NO_LAST_CHANGED_PRE_SCHEMA_31,
     literal(value=None, type_=Text).label("attributes"),
     literal(value=None, type_=Text).label("shared_attrs"),
 ]
 # Remove QUERY_STATES_PRE_SCHEMA_25
 # and the migration_in_progress check
 # once schema 26 is created
-QUERY_STATES_PRE_SCHEMA_25 = [
-    *BASE_STATES,
+_QUERY_STATES_PRE_SCHEMA_25 = [
+    *_BASE_STATES_PRE_SCHEMA_31,
     States.attributes,
     literal(value=None, type_=Text).label("shared_attrs"),
 ]
-QUERY_STATES_PRE_SCHEMA_25_NO_LAST_CHANGED = [
-    *BASE_STATES_NO_LAST_CHANGED,
+_QUERY_STATES_PRE_SCHEMA_25_NO_LAST_CHANGED = [
+    *_BASE_STATES_NO_LAST_CHANGED_PRE_SCHEMA_31,
     States.attributes,
     literal(value=None, type_=Text).label("shared_attrs"),
 ]
-QUERY_STATES = [
-    *BASE_STATES,
+_QUERY_STATES_PRE_SCHEMA_31 = [
+    *_BASE_STATES_PRE_SCHEMA_31,
     # Remove States.attributes once all attributes are in StateAttributes.shared_attrs
     States.attributes,
     StateAttributes.shared_attrs,
 ]
-QUERY_STATES_NO_LAST_CHANGED = [
-    *BASE_STATES_NO_LAST_CHANGED,
+_QUERY_STATES_NO_LAST_CHANGED_PRE_SCHEMA_31 = [
+    *_BASE_STATES_NO_LAST_CHANGED_PRE_SCHEMA_31,
+    # Remove States.attributes once all attributes are in StateAttributes.shared_attrs
+    States.attributes,
+    StateAttributes.shared_attrs,
+]
+_QUERY_STATES = [
+    *_BASE_STATES,
+    # Remove States.attributes once all attributes are in StateAttributes.shared_attrs
+    States.attributes,
+    StateAttributes.shared_attrs,
+]
+_QUERY_STATES_NO_LAST_CHANGED = [
+    *_BASE_STATES_NO_LAST_CHANGED,
     # Remove States.attributes once all attributes are in StateAttributes.shared_attrs
     States.attributes,
     StateAttributes.shared_attrs,
@@ -124,10 +158,25 @@ def lambda_stmt_and_join_attributes(
     # without the attributes fields and do not join the
     # state_attributes table
     if no_attributes:
+        if schema_version >= 31:
+            if include_last_changed:
+                return (
+                    lambda_stmt(lambda: select(*_QUERY_STATE_NO_ATTR)),
+                    False,
+                )
+            return (
+                lambda_stmt(lambda: select(*_QUERY_STATE_NO_ATTR_NO_LAST_CHANGED)),
+                False,
+            )
         if include_last_changed:
-            return lambda_stmt(lambda: select(*QUERY_STATE_NO_ATTR)), False
+            return (
+                lambda_stmt(lambda: select(*_QUERY_STATE_NO_ATTR_PRE_SCHEMA_31)),
+                False,
+            )
         return (
-            lambda_stmt(lambda: select(*QUERY_STATE_NO_ATTR_NO_LAST_CHANGED)),
+            lambda_stmt(
+                lambda: select(*_QUERY_STATE_NO_ATTR_NO_LAST_CHANGED_PRE_SCHEMA_31)
+            ),
             False,
         )
     # If we in the process of migrating schema we do
@@ -136,19 +185,27 @@ def lambda_stmt_and_join_attributes(
     if schema_version < 25:
         if include_last_changed:
             return (
-                lambda_stmt(lambda: select(*QUERY_STATES_PRE_SCHEMA_25)),
+                lambda_stmt(lambda: select(*_QUERY_STATES_PRE_SCHEMA_25)),
                 False,
             )
         return (
-            lambda_stmt(lambda: select(*QUERY_STATES_PRE_SCHEMA_25_NO_LAST_CHANGED)),
+            lambda_stmt(lambda: select(*_QUERY_STATES_PRE_SCHEMA_25_NO_LAST_CHANGED)),
             False,
         )
+
+    if schema_version >= 31:
+        if include_last_changed:
+            return lambda_stmt(lambda: select(*_QUERY_STATES)), True
+        return lambda_stmt(lambda: select(*_QUERY_STATES_NO_LAST_CHANGED)), True
     # Finally if no migration is in progress and no_attributes
     # was not requested, we query both attributes columns and
     # join state_attributes
     if include_last_changed:
-        return lambda_stmt(lambda: select(*QUERY_STATES)), True
-    return lambda_stmt(lambda: select(*QUERY_STATES_NO_LAST_CHANGED)), True
+        return lambda_stmt(lambda: select(*_QUERY_STATES_PRE_SCHEMA_31)), True
+    return (
+        lambda_stmt(lambda: select(*_QUERY_STATES_NO_LAST_CHANGED_PRE_SCHEMA_31)),
+        True,
+    )
 
 
 def get_significant_states(
@@ -211,22 +268,41 @@ def _significant_states_stmt(
         and significant_changes_only
         and split_entity_id(entity_ids[0])[0] not in SIGNIFICANT_DOMAINS
     ):
+        if schema_version >= 31:
+            stmt += lambda q: q.filter(
+                (States.last_changed_ts == States.last_updated_ts)
+                | States.last_changed_ts.is_(None)
+            )
         stmt += lambda q: q.filter(
             (States.last_changed == States.last_updated) | States.last_changed.is_(None)
         )
     elif significant_changes_only:
-        stmt += lambda q: q.filter(
-            or_(
-                *[
-                    States.entity_id.like(entity_domain)
-                    for entity_domain in SIGNIFICANT_DOMAINS_ENTITY_ID_LIKE
-                ],
-                (
-                    (States.last_changed == States.last_updated)
-                    | States.last_changed.is_(None)
-                ),
+        if schema_version >= 31:
+            stmt += lambda q: q.filter(
+                or_(
+                    *[
+                        States.entity_id.like(entity_domain)
+                        for entity_domain in SIGNIFICANT_DOMAINS_ENTITY_ID_LIKE
+                    ],
+                    (
+                        (States.last_changed_ts == States.last_updated_ts)
+                        | States.last_changed_ts.is_(None)
+                    ),
+                )
+            )
+        else:
+            stmt += lambda q: q.filter(
+                or_(
+                    *[
+                        States.entity_id.like(entity_domain)
+                        for entity_domain in SIGNIFICANT_DOMAINS_ENTITY_ID_LIKE
+                    ],
+                    (
+                        (States.last_changed == States.last_updated)
+                        | States.last_changed.is_(None)
+                    ),
+                )
             )
-        )
 
     if entity_ids:
         stmt += lambda q: q.filter(States.entity_id.in_(entity_ids))
@@ -238,15 +314,25 @@ def _significant_states_stmt(
                 lambda q: q.filter(entity_filter), track_on=[filters]
             )
 
-    stmt += lambda q: q.filter(States.last_updated > start_time)
-    if end_time:
-        stmt += lambda q: q.filter(States.last_updated < end_time)
+    if schema_version >= 31:
+        start_time_ts = start_time.timestamp()
+        stmt += lambda q: q.filter(States.last_updated_ts > start_time_ts)
+        if end_time:
+            end_time_ts = end_time.timestamp()
+            stmt += lambda q: q.filter(States.last_updated_ts < end_time_ts)
+    else:
+        stmt += lambda q: q.filter(States.last_updated > start_time)
+        if end_time:
+            stmt += lambda q: q.filter(States.last_updated < end_time)
 
     if join_attributes:
         stmt += lambda q: q.outerjoin(
             StateAttributes, States.attributes_id == StateAttributes.attributes_id
         )
-    stmt += lambda q: q.order_by(States.entity_id, States.last_updated)
+    if schema_version >= 31:
+        stmt += lambda q: q.order_by(States.entity_id, States.last_updated_ts)
+    else:
+        stmt += lambda q: q.order_by(States.entity_id, States.last_updated)
     return stmt
 
 
@@ -312,7 +398,11 @@ def get_full_significant_states_with_session(
     significant_changes_only: bool = True,
     no_attributes: bool = False,
 ) -> MutableMapping[str, list[State]]:
-    """Variant of get_significant_states_with_session that does not return minimal responses."""
+    """Variant of get_significant_states_with_session.
+
+    Difference with get_significant_states_with_session is that it does not
+    return minimal responses.
+    """
     return cast(
         MutableMapping[str, list[State]],
         get_significant_states_with_session(
@@ -342,12 +432,29 @@ def _state_changed_during_period_stmt(
     stmt, join_attributes = lambda_stmt_and_join_attributes(
         schema_version, no_attributes, include_last_changed=False
     )
-    stmt += lambda q: q.filter(
-        ((States.last_changed == States.last_updated) | States.last_changed.is_(None))
-        & (States.last_updated > start_time)
-    )
+    if schema_version >= 31:
+        start_time_ts = start_time.timestamp()
+        stmt += lambda q: q.filter(
+            (
+                (States.last_changed_ts == States.last_updated_ts)
+                | States.last_changed_ts.is_(None)
+            )
+            & (States.last_updated_ts > start_time_ts)
+        )
+    else:
+        stmt += lambda q: q.filter(
+            (
+                (States.last_changed == States.last_updated)
+                | States.last_changed.is_(None)
+            )
+            & (States.last_updated > start_time)
+        )
     if end_time:
-        stmt += lambda q: q.filter(States.last_updated < end_time)
+        if schema_version >= 31:
+            end_time_ts = end_time.timestamp()
+            stmt += lambda q: q.filter(States.last_updated_ts < end_time_ts)
+        else:
+            stmt += lambda q: q.filter(States.last_updated < end_time)
     if entity_id:
         stmt += lambda q: q.filter(States.entity_id == entity_id)
     if join_attributes:
@@ -355,9 +462,17 @@ def _state_changed_during_period_stmt(
             StateAttributes, States.attributes_id == StateAttributes.attributes_id
         )
     if descending:
-        stmt += lambda q: q.order_by(States.entity_id, States.last_updated.desc())
+        if schema_version >= 31:
+            stmt += lambda q: q.order_by(
+                States.entity_id, States.last_updated_ts.desc()
+            )
+        else:
+            stmt += lambda q: q.order_by(States.entity_id, States.last_updated.desc())
     else:
-        stmt += lambda q: q.order_by(States.entity_id, States.last_updated)
+        if schema_version >= 31:
+            stmt += lambda q: q.order_by(States.entity_id, States.last_updated_ts)
+        else:
+            stmt += lambda q: q.order_by(States.entity_id, States.last_updated)
     if limit:
         stmt += lambda q: q.limit(limit)
     return stmt
@@ -404,37 +519,52 @@ def state_changes_during_period(
 
 
 def _get_last_state_changes_stmt(
-    schema_version: int, number_of_states: int, entity_id: str | None
+    schema_version: int, number_of_states: int, entity_id: str
 ) -> StatementLambdaElement:
     stmt, join_attributes = lambda_stmt_and_join_attributes(
         schema_version, False, include_last_changed=False
     )
-    stmt += lambda q: q.filter(
-        (States.last_changed == States.last_updated) | States.last_changed.is_(None)
-    )
-    if entity_id:
-        stmt += lambda q: q.filter(States.entity_id == entity_id)
+    if schema_version >= 31:
+        stmt += lambda q: q.where(
+            States.state_id
+            == (
+                select(States.state_id)
+                .filter(States.entity_id == entity_id)
+                .order_by(States.last_updated_ts.desc())
+                .limit(number_of_states)
+                .subquery()
+            ).c.state_id
+        )
+    else:
+        stmt += lambda q: q.where(
+            States.state_id
+            == (
+                select(States.state_id)
+                .filter(States.entity_id == entity_id)
+                .order_by(States.last_updated.desc())
+                .limit(number_of_states)
+                .subquery()
+            ).c.state_id
+        )
     if join_attributes:
         stmt += lambda q: q.outerjoin(
             StateAttributes, States.attributes_id == StateAttributes.attributes_id
         )
-    stmt += lambda q: q.order_by(States.entity_id, States.last_updated.desc()).limit(
-        number_of_states
-    )
+
+    stmt += lambda q: q.order_by(States.state_id.desc())
     return stmt
 
 
 def get_last_state_changes(
-    hass: HomeAssistant, number_of_states: int, entity_id: str | None
+    hass: HomeAssistant, number_of_states: int, entity_id: str
 ) -> MutableMapping[str, list[State]]:
     """Return the last number_of_states."""
-    start_time = dt_util.utcnow()
-    entity_id = entity_id.lower() if entity_id is not None else None
-    entity_ids = [entity_id] if entity_id is not None else None
+    entity_id_lower = entity_id.lower()
+    entity_ids = [entity_id_lower]
 
     with session_scope(hass=hass) as session:
         stmt = _get_last_state_changes_stmt(
-            _schema_version(hass), number_of_states, entity_id
+            _schema_version(hass), number_of_states, entity_id_lower
         )
         states = list(execute_stmt_lambda_element(session, stmt))
         return cast(
@@ -443,7 +573,7 @@ def get_last_state_changes(
                 hass,
                 session,
                 reversed(states),
-                start_time,
+                dt_util.utcnow(),
                 entity_ids,
                 include_start_time_state=False,
             ),
@@ -463,19 +593,36 @@ def _get_states_for_entites_stmt(
     )
     # We got an include-list of entities, accelerate the query by filtering already
     # in the inner query.
-    stmt += lambda q: q.where(
-        States.state_id
-        == (
-            select(func.max(States.state_id).label("max_state_id"))
-            .filter(
-                (States.last_updated >= run_start)
-                & (States.last_updated < utc_point_in_time)
-            )
-            .filter(States.entity_id.in_(entity_ids))
-            .group_by(States.entity_id)
-            .subquery()
-        ).c.max_state_id
-    )
+    if schema_version >= 31:
+        run_start_ts = process_timestamp(run_start).timestamp()
+        utc_point_in_time_ts = dt_util.utc_to_timestamp(utc_point_in_time)
+        stmt += lambda q: q.where(
+            States.state_id
+            == (
+                select(func.max(States.state_id).label("max_state_id"))
+                .filter(
+                    (States.last_updated_ts >= run_start_ts)
+                    & (States.last_updated_ts < utc_point_in_time_ts)
+                )
+                .filter(States.entity_id.in_(entity_ids))
+                .group_by(States.entity_id)
+                .subquery()
+            ).c.max_state_id
+        )
+    else:
+        stmt += lambda q: q.where(
+            States.state_id
+            == (
+                select(func.max(States.state_id).label("max_state_id"))
+                .filter(
+                    (States.last_updated >= run_start)
+                    & (States.last_updated < utc_point_in_time)
+                )
+                .filter(States.entity_id.in_(entity_ids))
+                .group_by(States.entity_id)
+                .subquery()
+            ).c.max_state_id
+        )
     if join_attributes:
         stmt += lambda q: q.outerjoin(
             StateAttributes, (States.attributes_id == StateAttributes.attributes_id)
@@ -484,10 +631,26 @@ def _get_states_for_entites_stmt(
 
 
 def _generate_most_recent_states_by_date(
+    schema_version: int,
     run_start: datetime,
     utc_point_in_time: datetime,
 ) -> Subquery:
     """Generate the sub query for the most recent states by data."""
+    if schema_version >= 31:
+        run_start_ts = process_timestamp(run_start).timestamp()
+        utc_point_in_time_ts = dt_util.utc_to_timestamp(utc_point_in_time)
+        return (
+            select(
+                States.entity_id.label("max_entity_id"),
+                func.max(States.last_updated_ts).label("max_last_updated"),
+            )
+            .filter(
+                (States.last_updated_ts >= run_start_ts)
+                & (States.last_updated_ts < utc_point_in_time_ts)
+            )
+            .group_by(States.entity_id)
+            .subquery()
+        )
     return (
         select(
             States.entity_id.label("max_entity_id"),
@@ -518,24 +681,42 @@ def _get_states_for_all_stmt(
     # This filtering can't be done in the inner query because the domain column is
     # not indexed and we can't control what's in the custom filter.
     most_recent_states_by_date = _generate_most_recent_states_by_date(
-        run_start, utc_point_in_time
-    )
-    stmt += lambda q: q.where(
-        States.state_id
-        == (
-            select(func.max(States.state_id).label("max_state_id"))
-            .join(
-                most_recent_states_by_date,
-                and_(
-                    States.entity_id == most_recent_states_by_date.c.max_entity_id,
-                    States.last_updated
-                    == most_recent_states_by_date.c.max_last_updated,
-                ),
-            )
-            .group_by(States.entity_id)
-            .subquery()
-        ).c.max_state_id,
+        schema_version, run_start, utc_point_in_time
     )
+    if schema_version >= 31:
+        stmt += lambda q: q.where(
+            States.state_id
+            == (
+                select(func.max(States.state_id).label("max_state_id"))
+                .join(
+                    most_recent_states_by_date,
+                    and_(
+                        States.entity_id == most_recent_states_by_date.c.max_entity_id,
+                        States.last_updated_ts
+                        == most_recent_states_by_date.c.max_last_updated,
+                    ),
+                )
+                .group_by(States.entity_id)
+                .subquery()
+            ).c.max_state_id,
+        )
+    else:
+        stmt += lambda q: q.where(
+            States.state_id
+            == (
+                select(func.max(States.state_id).label("max_state_id"))
+                .join(
+                    most_recent_states_by_date,
+                    and_(
+                        States.entity_id == most_recent_states_by_date.c.max_entity_id,
+                        States.last_updated
+                        == most_recent_states_by_date.c.max_last_updated,
+                    ),
+                )
+                .group_by(States.entity_id)
+                .subquery()
+            ).c.max_state_id,
+        )
     stmt += _ignore_domains_filter
     if filters and filters.has_config:
         entity_filter = filters.states_entity_filter()
@@ -598,14 +779,25 @@ def _get_single_entity_states_stmt(
     stmt, join_attributes = lambda_stmt_and_join_attributes(
         schema_version, no_attributes, include_last_changed=True
     )
-    stmt += (
-        lambda q: q.filter(
-            States.last_updated < utc_point_in_time,
-            States.entity_id == entity_id,
+    if schema_version >= 31:
+        utc_point_in_time_ts = dt_util.utc_to_timestamp(utc_point_in_time)
+        stmt += (
+            lambda q: q.filter(
+                States.last_updated_ts < utc_point_in_time_ts,
+                States.entity_id == entity_id,
+            )
+            .order_by(States.last_updated_ts.desc())
+            .limit(1)
+        )
+    else:
+        stmt += (
+            lambda q: q.filter(
+                States.last_updated < utc_point_in_time,
+                States.entity_id == entity_id,
+            )
+            .order_by(States.last_updated.desc())
+            .limit(1)
         )
-        .order_by(States.last_updated.desc())
-        .limit(1)
-    )
     if join_attributes:
         stmt += lambda q: q.outerjoin(
             StateAttributes, States.attributes_id == StateAttributes.attributes_id
@@ -636,15 +828,24 @@ def _sorted_states_to_dict(
     each list of states, otherwise our graphs won't start on the Y
     axis correctly.
     """
+    schema_version = _schema_version(hass)
+    _process_timestamp: Callable[[datetime], float | str]
+    state_class: Callable[
+        [Row, dict[str, dict[str, Any]], datetime | None], State | dict[str, Any]
+    ]
     if compressed_state_format:
-        state_class = row_to_compressed_state
-        _process_timestamp: Callable[
-            [datetime], float | str
-        ] = process_datetime_to_timestamp
+        if schema_version >= 31:
+            state_class = row_to_compressed_state
+        else:
+            state_class = row_to_compressed_state_pre_schema_31
+        _process_timestamp = process_datetime_to_timestamp
         attr_time = COMPRESSED_STATE_LAST_UPDATED
         attr_state = COMPRESSED_STATE_STATE
     else:
-        state_class = LazyState  # type: ignore[assignment]
+        if schema_version >= 31:
+            state_class = LazyState
+        else:
+            state_class = LazyStatePreSchema31
         _process_timestamp = process_timestamp_to_utc_isoformat
         attr_time = LAST_CHANGED_KEY
         attr_state = STATE_KEY
@@ -692,7 +893,9 @@ def _sorted_states_to_dict(
             ent_results.append(state_class(row, attr_cache, start_time))
 
         if not minimal_response or split_entity_id(ent_id)[0] in NEED_ATTRIBUTE_DOMAINS:
-            ent_results.extend(state_class(db_state, attr_cache) for db_state in group)
+            ent_results.extend(
+                state_class(db_state, attr_cache, None) for db_state in group
+            )
             continue
 
         # With minimal response we only provide a native
@@ -703,26 +906,49 @@ def _sorted_states_to_dict(
             if (first_state := next(group, None)) is None:
                 continue
             prev_state = first_state.state
-            ent_results.append(state_class(first_state, attr_cache))
+            ent_results.append(state_class(first_state, attr_cache, None))
+
+        #
+        # minimal_response only makes sense with last_updated == last_updated
+        #
+        # We use last_updated for for last_changed since its the same
+        #
+        # With minimal response we do not care about attribute
+        # changes so we can filter out duplicate states
+        if schema_version < 31:
+            for row in group:
+                if (state := row.state) != prev_state:
+                    ent_results.append(
+                        {
+                            attr_state: state,
+                            attr_time: _process_timestamp(row.last_updated),
+                        }
+                    )
+                    prev_state = state
+            continue
+
+        if compressed_state_format:
+            for row in group:
+                if (state := row.state) != prev_state:
+                    ent_results.append(
+                        {
+                            attr_state: state,
+                            attr_time: row.last_updated_ts,
+                        }
+                    )
+                    prev_state = state
 
         for row in group:
-            # With minimal response we do not care about attribute
-            # changes so we can filter out duplicate states
-            if (state := row.state) == prev_state:
-                continue
-
-            ent_results.append(
-                {
-                    attr_state: state,
-                    #
-                    # minimal_response only makes sense with last_updated == last_updated
-                    #
-                    # We use last_updated for for last_changed since its the same
-                    #
-                    attr_time: _process_timestamp(row.last_updated),
-                }
-            )
-            prev_state = state
+            if (state := row.state) != prev_state:
+                ent_results.append(
+                    {
+                        attr_state: state,
+                        attr_time: process_timestamp_to_utc_isoformat(
+                            dt_util.utc_from_timestamp(row.last_updated_ts)
+                        ),
+                    }
+                )
+                prev_state = state
 
     # If there are no states beyond the initial state,
     # the state a was never popped from initial_states
