@@ -4,6 +4,3 @@ DOMAIN = "reolink"
 
 CONF_USE_HTTPS = "use_https"
 CONF_PROTOCOL = "protocol"
-
-DEFAULT_PROTOCOL = "rtsp"
-DEFAULT_TIMEOUT = 60
