@@ -8,16 +8,14 @@ from dataclasses import dataclass
 from datetime import date, datetime, timedelta, timezone
 from decimal import Decimal, InvalidOperation as DecimalInvalidOperation
 import logging
-from math import floor, log10
+from math import ceil, floor, log10
+import re
 from typing import Any, Final, cast, final
 
-import voluptuous as vol
-
-from homeassistant.backports.enum import StrEnum
 from homeassistant.config_entries import ConfigEntry
-from homeassistant.const import (  # noqa: F401, pylint: disable=[hass-deprecated-import]
-    CONCENTRATION_MICROGRAMS_PER_CUBIC_METER,
-    CONCENTRATION_PARTS_PER_MILLION,
+
+# pylint: disable=[hass-deprecated-import]
+from homeassistant.const import (  # noqa: F401
     CONF_UNIT_OF_MEASUREMENT,
     DEVICE_CLASS_AQI,
     DEVICE_CLASS_BATTERY,
@@ -47,34 +45,11 @@ from homeassistant.const import (  # noqa: F401, pylint: disable=[hass-deprecate
     DEVICE_CLASS_TIMESTAMP,
     DEVICE_CLASS_VOLATILE_ORGANIC_COMPOUNDS,
     DEVICE_CLASS_VOLTAGE,
-    LIGHT_LUX,
-    PERCENTAGE,
-    POWER_VOLT_AMPERE_REACTIVE,
-    SIGNAL_STRENGTH_DECIBELS,
-    SIGNAL_STRENGTH_DECIBELS_MILLIWATT,
-    UnitOfApparentPower,
-    UnitOfDataRate,
-    UnitOfElectricCurrent,
-    UnitOfElectricPotential,
-    UnitOfEnergy,
-    UnitOfFrequency,
-    UnitOfInformation,
-    UnitOfIrradiance,
-    UnitOfLength,
-    UnitOfMass,
-    UnitOfPower,
-    UnitOfPrecipitationDepth,
-    UnitOfPressure,
-    UnitOfSoundPressure,
-    UnitOfSpeed,
     UnitOfTemperature,
-    UnitOfTime,
-    UnitOfVolume,
-    UnitOfVolumetricFlux,
 )
 from homeassistant.core import HomeAssistant, callback
 from homeassistant.helpers import entity_registry as er
-from homeassistant.helpers.config_validation import (  # noqa: F401
+from homeassistant.helpers.config_validation import (
     PLATFORM_SCHEMA,
     PLATFORM_SCHEMA_BASE,
 )
@@ -82,477 +57,53 @@ from homeassistant.helpers.entity import Entity, EntityDescription
 from homeassistant.helpers.entity_component import EntityComponent
 from homeassistant.helpers.entity_platform import EntityPlatform
 from homeassistant.helpers.restore_state import ExtraStoredData, RestoreEntity
-from homeassistant.helpers.typing import ConfigType, StateType
+from homeassistant.helpers.typing import UNDEFINED, ConfigType, StateType, UndefinedType
 from homeassistant.util import dt as dt_util
-from homeassistant.util.unit_conversion import (
-    BaseUnitConverter,
-    DataRateConverter,
-    DistanceConverter,
-    ElectricCurrentConverter,
-    ElectricPotentialConverter,
-    InformationConverter,
-    MassConverter,
-    PressureConverter,
-    SpeedConverter,
-    TemperatureConverter,
-    VolumeConverter,
-)
 
-from .const import CONF_STATE_CLASS  # noqa: F401
+from .const import (  # noqa: F401
+    ATTR_LAST_RESET,
+    ATTR_OPTIONS,
+    ATTR_STATE_CLASS,
+    CONF_STATE_CLASS,
+    DEVICE_CLASS_STATE_CLASSES,
+    DEVICE_CLASS_UNITS,
+    DEVICE_CLASSES,
+    DEVICE_CLASSES_SCHEMA,
+    DOMAIN,
+    STATE_CLASS_MEASUREMENT,
+    STATE_CLASS_TOTAL,
+    STATE_CLASS_TOTAL_INCREASING,
+    STATE_CLASSES,
+    STATE_CLASSES_SCHEMA,
+    UNIT_CONVERTERS,
+    SensorDeviceClass,
+    SensorStateClass,
+)
+from .websocket_api import async_setup as async_setup_ws_api
 
 _LOGGER: Final = logging.getLogger(__name__)
 
-ATTR_LAST_RESET: Final = "last_reset"
-ATTR_STATE_CLASS: Final = "state_class"
-ATTR_OPTIONS: Final = "options"
-
-DOMAIN: Final = "sensor"
-
 ENTITY_ID_FORMAT: Final = DOMAIN + ".{}"
 
+NEGATIVE_ZERO_PATTERN = re.compile(r"^-(0\.?0*)$")
+
 SCAN_INTERVAL: Final = timedelta(seconds=30)
 
-
-class SensorDeviceClass(StrEnum):
-    """Device class for sensors."""
-
-    # Non-numerical device classes
-    DATE = "date"
-    """Date.
-
-    Unit of measurement: `None`
-
-    ISO8601 format: https://en.wikipedia.org/wiki/ISO_8601
-    """
-
-    DURATION = "duration"
-    """Fixed duration.
-
-    Unit of measurement: `d`, `h`, `min`, `s`
-    """
-
-    ENUM = "enum"
-    """Enumeration.
-
-    Provides a fixed list of options the state of the sensor can be in.
-
-    Unit of measurement: `None`
-    """
-
-    TIMESTAMP = "timestamp"
-    """Timestamp.
-
-    Unit of measurement: `None`
-
-    ISO8601 format: https://en.wikipedia.org/wiki/ISO_8601
-    """
-
-    # Numerical device classes, these should be aligned with NumberDeviceClass
-    APPARENT_POWER = "apparent_power"
-    """Apparent power.
-
-    Unit of measurement: `VA`
-    """
-
-    AQI = "aqi"
-    """Air Quality Index.
-
-    Unit of measurement: `None`
-    """
-
-    ATMOSPHERIC_PRESSURE = "atmospheric_pressure"
-    """Atmospheric pressure.
-
-    Unit of measurement: `UnitOfPressure` units
-    """
-
-    BATTERY = "battery"
-    """Percentage of battery that is left.
-
-    Unit of measurement: `%`
-    """
-
-    CO = "carbon_monoxide"
-    """Carbon Monoxide gas concentration.
-
-    Unit of measurement: `ppm` (parts per million)
-    """
-
-    CO2 = "carbon_dioxide"
-    """Carbon Dioxide gas concentration.
-
-    Unit of measurement: `ppm` (parts per million)
-    """
-
-    CURRENT = "current"
-    """Current.
-
-    Unit of measurement: `A`, `mA`
-    """
-
-    DATA_RATE = "data_rate"
-    """Data rate.
-
-    Unit of measurement: UnitOfDataRate
-    """
-
-    DATA_SIZE = "data_size"
-    """Data size.
-
-    Unit of measurement: UnitOfInformation
-    """
-
-    DISTANCE = "distance"
-    """Generic distance.
-
-    Unit of measurement: `LENGTH_*` units
-    - SI /metric: `mm`, `cm`, `m`, `km`
-    - USCS / imperial: `in`, `ft`, `yd`, `mi`
-    """
-
-    ENERGY = "energy"
-    """Energy.
-
-    Unit of measurement: `Wh`, `kWh`, `MWh`, `GJ`
-    """
-
-    FREQUENCY = "frequency"
-    """Frequency.
-
-    Unit of measurement: `Hz`, `kHz`, `MHz`, `GHz`
-    """
-
-    GAS = "gas"
-    """Gas.
-
-    Unit of measurement:
-    - SI / metric: `m³`
-    - USCS / imperial: `ft³`, `CCF`
-    """
-
-    HUMIDITY = "humidity"
-    """Relative humidity.
-
-    Unit of measurement: `%`
-    """
-
-    ILLUMINANCE = "illuminance"
-    """Illuminance.
-
-    Unit of measurement: `lx`
-    """
-
-    IRRADIANCE = "irradiance"
-    """Irradiance.
-
-    Unit of measurement:
-    - SI / metric: `W/m²`
-    - USCS / imperial: `BTU/(h⋅ft²)`
-    """
-
-    MOISTURE = "moisture"
-    """Moisture.
-
-    Unit of measurement: `%`
-    """
-
-    MONETARY = "monetary"
-    """Amount of money.
-
-    Unit of measurement: ISO4217 currency code
-
-    See https://en.wikipedia.org/wiki/ISO_4217#Active_codes for active codes
-    """
-
-    NITROGEN_DIOXIDE = "nitrogen_dioxide"
-    """Amount of NO2.
-
-    Unit of measurement: `µg/m³`
-    """
-
-    NITROGEN_MONOXIDE = "nitrogen_monoxide"
-    """Amount of NO.
-
-    Unit of measurement: `µg/m³`
-    """
-
-    NITROUS_OXIDE = "nitrous_oxide"
-    """Amount of N2O.
-
-    Unit of measurement: `µg/m³`
-    """
-
-    OZONE = "ozone"
-    """Amount of O3.
-
-    Unit of measurement: `µg/m³`
-    """
-
-    PM1 = "pm1"
-    """Particulate matter <= 0.1 μm.
-
-    Unit of measurement: `µg/m³`
-    """
-
-    PM10 = "pm10"
-    """Particulate matter <= 10 μm.
-
-    Unit of measurement: `µg/m³`
-    """
-
-    PM25 = "pm25"
-    """Particulate matter <= 2.5 μm.
-
-    Unit of measurement: `µg/m³`
-    """
-
-    POWER_FACTOR = "power_factor"
-    """Power factor.
-
-    Unit of measurement: `%`
-    """
-
-    POWER = "power"
-    """Power.
-
-    Unit of measurement: `W`, `kW`
-    """
-
-    PRECIPITATION = "precipitation"
-    """Precipitation.
-
-    Unit of measurement: UnitOfPrecipitationDepth
-    - SI / metric: `cm`, `mm`
-    - USCS / imperial: `in`
-    """
-
-    PRECIPITATION_INTENSITY = "precipitation_intensity"
-    """Precipitation intensity.
-
-    Unit of measurement: UnitOfVolumetricFlux
-    - SI /metric: `mm/d`, `mm/h`
-    - USCS / imperial: `in/d`, `in/h`
-    """
-
-    PRESSURE = "pressure"
-    """Pressure.
-
-    Unit of measurement:
-    - `mbar`, `cbar`, `bar`
-    - `Pa`, `hPa`, `kPa`
-    - `inHg`
-    - `psi`
-    """
-
-    REACTIVE_POWER = "reactive_power"
-    """Reactive power.
-
-    Unit of measurement: `var`
-    """
-
-    SIGNAL_STRENGTH = "signal_strength"
-    """Signal strength.
-
-    Unit of measurement: `dB`, `dBm`
-    """
-
-    SOUND_PRESSURE = "sound_pressure"
-    """Sound pressure.
-
-    Unit of measurement: `dB`, `dBA`
-    """
-
-    SPEED = "speed"
-    """Generic speed.
-
-    Unit of measurement: `SPEED_*` units or `UnitOfVolumetricFlux`
-    - SI /metric: `mm/d`, `mm/h`, `m/s`, `km/h`
-    - USCS / imperial: `in/d`, `in/h`, `ft/s`, `mph`
-    - Nautical: `kn`
-    """
-
-    SULPHUR_DIOXIDE = "sulphur_dioxide"
-    """Amount of SO2.
-
-    Unit of measurement: `µg/m³`
-    """
-
-    TEMPERATURE = "temperature"
-    """Temperature.
-
-    Unit of measurement: `°C`, `°F`
-    """
-
-    VOLATILE_ORGANIC_COMPOUNDS = "volatile_organic_compounds"
-    """Amount of VOC.
-
-    Unit of measurement: `µg/m³`
-    """
-
-    VOLTAGE = "voltage"
-    """Voltage.
-
-    Unit of measurement: `V`, `mV`
-    """
-
-    VOLUME = "volume"
-    """Generic volume.
-
-    Unit of measurement: `VOLUME_*` units
-    - SI / metric: `mL`, `L`, `m³`
-    - USCS / imperial: `ft³`, `CCF`, `fl. oz.`, `gal` (warning: volumes expressed in
-    USCS/imperial units are currently assumed to be US volumes)
-    """
-
-    WATER = "water"
-    """Water.
-
-    Unit of measurement:
-    - SI / metric: `m³`, `L`
-    - USCS / imperial: `ft³`, `CCF`, `gal` (warning: volumes expressed in
-    USCS/imperial units are currently assumed to be US volumes)
-    """
-
-    WEIGHT = "weight"
-    """Generic weight, represents a measurement of an object's mass.
-
-    Weight is used instead of mass to fit with every day language.
-
-    Unit of measurement: `MASS_*` units
-    - SI / metric: `µg`, `mg`, `g`, `kg`
-    - USCS / imperial: `oz`, `lb`
-    """
-
-    WIND_SPEED = "wind_speed"
-    """Wind speed.
-
-    Unit of measurement: `SPEED_*` units
-    - SI /metric: `m/s`, `km/h`
-    - USCS / imperial: `ft/s`, `mph`
-    - Nautical: `kn`
-    """
-
-
-DEVICE_CLASSES_SCHEMA: Final = vol.All(vol.Lower, vol.Coerce(SensorDeviceClass))
-
-# DEVICE_CLASSES is deprecated as of 2021.12
-# use the SensorDeviceClass enum instead.
-DEVICE_CLASSES: Final[list[str]] = [cls.value for cls in SensorDeviceClass]
-
-
-class SensorStateClass(StrEnum):
-    """State class for sensors."""
-
-    MEASUREMENT = "measurement"
-    """The state represents a measurement in present time."""
-
-    TOTAL = "total"
-    """The state represents a total amount.
-
-    For example: net energy consumption"""
-
-    TOTAL_INCREASING = "total_increasing"
-    """The state represents a monotonically increasing total.
-
-    For example: an amount of consumed gas"""
-
-
-STATE_CLASSES_SCHEMA: Final = vol.All(vol.Lower, vol.Coerce(SensorStateClass))
-
-
-# STATE_CLASS* is deprecated as of 2021.12
-# use the SensorStateClass enum instead.
-STATE_CLASS_MEASUREMENT: Final = "measurement"
-STATE_CLASS_TOTAL: Final = "total"
-STATE_CLASS_TOTAL_INCREASING: Final = "total_increasing"
-STATE_CLASSES: Final[list[str]] = [cls.value for cls in SensorStateClass]
-
-# Note: this needs to be aligned with frontend: OVERRIDE_SENSOR_UNITS in
-# `entity-registry-settings.ts`
-UNIT_CONVERTERS: dict[SensorDeviceClass | str | None, type[BaseUnitConverter]] = {
-    SensorDeviceClass.DATA_RATE: DataRateConverter,
-    SensorDeviceClass.DATA_SIZE: InformationConverter,
-    SensorDeviceClass.DISTANCE: DistanceConverter,
-    SensorDeviceClass.CURRENT: ElectricCurrentConverter,
-    SensorDeviceClass.GAS: VolumeConverter,
-    SensorDeviceClass.PRECIPITATION: DistanceConverter,
-    SensorDeviceClass.PRESSURE: PressureConverter,
-    SensorDeviceClass.SPEED: SpeedConverter,
-    SensorDeviceClass.TEMPERATURE: TemperatureConverter,
-    SensorDeviceClass.VOLTAGE: ElectricPotentialConverter,
-    SensorDeviceClass.VOLUME: VolumeConverter,
-    SensorDeviceClass.WATER: VolumeConverter,
-    SensorDeviceClass.WEIGHT: MassConverter,
-    SensorDeviceClass.WIND_SPEED: SpeedConverter,
-}
-
-DEVICE_CLASS_UNITS: dict[SensorDeviceClass, set[type[StrEnum] | str | None]] = {
-    SensorDeviceClass.APPARENT_POWER: set(UnitOfApparentPower),
-    SensorDeviceClass.AQI: {None},
-    SensorDeviceClass.ATMOSPHERIC_PRESSURE: set(UnitOfPressure),
-    SensorDeviceClass.BATTERY: {PERCENTAGE},
-    SensorDeviceClass.CO: {CONCENTRATION_PARTS_PER_MILLION},
-    SensorDeviceClass.CO2: {CONCENTRATION_PARTS_PER_MILLION},
-    SensorDeviceClass.CURRENT: set(UnitOfElectricCurrent),
-    SensorDeviceClass.DATA_RATE: set(UnitOfDataRate),
-    SensorDeviceClass.DATA_SIZE: set(UnitOfInformation),
-    SensorDeviceClass.DISTANCE: set(UnitOfLength),
-    SensorDeviceClass.DURATION: {
-        UnitOfTime.DAYS,
-        UnitOfTime.HOURS,
-        UnitOfTime.MINUTES,
-        UnitOfTime.SECONDS,
-    },
-    SensorDeviceClass.ENERGY: set(UnitOfEnergy),
-    SensorDeviceClass.FREQUENCY: set(UnitOfFrequency),
-    SensorDeviceClass.GAS: {
-        UnitOfVolume.CENTUM_CUBIC_FEET,
-        UnitOfVolume.CUBIC_FEET,
-        UnitOfVolume.CUBIC_METERS,
-    },
-    SensorDeviceClass.HUMIDITY: {PERCENTAGE},
-    SensorDeviceClass.ILLUMINANCE: {LIGHT_LUX},
-    SensorDeviceClass.IRRADIANCE: set(UnitOfIrradiance),
-    SensorDeviceClass.MOISTURE: {PERCENTAGE},
-    SensorDeviceClass.NITROGEN_DIOXIDE: {CONCENTRATION_MICROGRAMS_PER_CUBIC_METER},
-    SensorDeviceClass.NITROGEN_MONOXIDE: {CONCENTRATION_MICROGRAMS_PER_CUBIC_METER},
-    SensorDeviceClass.NITROUS_OXIDE: {CONCENTRATION_MICROGRAMS_PER_CUBIC_METER},
-    SensorDeviceClass.OZONE: {CONCENTRATION_MICROGRAMS_PER_CUBIC_METER},
-    SensorDeviceClass.PM1: {CONCENTRATION_MICROGRAMS_PER_CUBIC_METER},
-    SensorDeviceClass.PM10: {CONCENTRATION_MICROGRAMS_PER_CUBIC_METER},
-    SensorDeviceClass.PM25: {CONCENTRATION_MICROGRAMS_PER_CUBIC_METER},
-    SensorDeviceClass.POWER_FACTOR: {PERCENTAGE},
-    SensorDeviceClass.POWER: {UnitOfPower.WATT, UnitOfPower.KILO_WATT},
-    SensorDeviceClass.PRECIPITATION: set(UnitOfPrecipitationDepth),
-    SensorDeviceClass.PRECIPITATION_INTENSITY: set(UnitOfVolumetricFlux),
-    SensorDeviceClass.PRESSURE: set(UnitOfPressure),
-    SensorDeviceClass.REACTIVE_POWER: {POWER_VOLT_AMPERE_REACTIVE},
-    SensorDeviceClass.SIGNAL_STRENGTH: {
-        SIGNAL_STRENGTH_DECIBELS,
-        SIGNAL_STRENGTH_DECIBELS_MILLIWATT,
-    },
-    SensorDeviceClass.SOUND_PRESSURE: set(UnitOfSoundPressure),
-    SensorDeviceClass.SPEED: set(UnitOfSpeed).union(set(UnitOfVolumetricFlux)),
-    SensorDeviceClass.SULPHUR_DIOXIDE: {CONCENTRATION_MICROGRAMS_PER_CUBIC_METER},
-    SensorDeviceClass.TEMPERATURE: {
-        UnitOfTemperature.CELSIUS,
-        UnitOfTemperature.FAHRENHEIT,
-    },
-    SensorDeviceClass.VOLATILE_ORGANIC_COMPOUNDS: {
-        CONCENTRATION_MICROGRAMS_PER_CUBIC_METER
-    },
-    SensorDeviceClass.VOLTAGE: set(UnitOfElectricPotential),
-    SensorDeviceClass.VOLUME: set(UnitOfVolume),
-    SensorDeviceClass.WATER: {
-        UnitOfVolume.CENTUM_CUBIC_FEET,
-        UnitOfVolume.CUBIC_FEET,
-        UnitOfVolume.CUBIC_METERS,
-        UnitOfVolume.GALLONS,
-        UnitOfVolume.LITERS,
-    },
-    SensorDeviceClass.WEIGHT: set(UnitOfMass),
-    SensorDeviceClass.WIND_SPEED: set(UnitOfSpeed),
-}
+__all__ = [
+    "ATTR_LAST_RESET",
+    "ATTR_OPTIONS",
+    "ATTR_STATE_CLASS",
+    "CONF_STATE_CLASS",
+    "DOMAIN",
+    "PLATFORM_SCHEMA_BASE",
+    "PLATFORM_SCHEMA",
+    "RestoreSensor",
+    "SensorDeviceClass",
+    "SensorEntity",
+    "SensorEntityDescription",
+    "SensorExtraStoredData",
+    "SensorStateClass",
+]
 
 # mypy: disallow-any-generics
 
@@ -563,6 +114,7 @@ async def async_setup(hass: HomeAssistant, config: ConfigType) -> bool:
         _LOGGER, DOMAIN, hass, SCAN_INTERVAL
     )
 
+    async_setup_ws_api(hass)
     await component.async_setup(config)
     return True
 
@@ -584,11 +136,12 @@ class SensorEntityDescription(EntityDescription):
     """A class that describes sensor entities."""
 
     device_class: SensorDeviceClass | None = None
-    suggested_unit_of_measurement: str | None = None
     last_reset: datetime | None = None
+    native_precision: int | None = None
     native_unit_of_measurement: str | None = None
-    state_class: SensorStateClass | str | None = None
     options: list[str] | None = None
+    state_class: SensorStateClass | str | None = None
+    suggested_unit_of_measurement: str | None = None
     unit_of_measurement: None = None  # Type override, use native_unit_of_measurement
 
 
@@ -598,6 +151,7 @@ class SensorEntity(Entity):
     entity_description: SensorEntityDescription
     _attr_device_class: SensorDeviceClass | None
     _attr_last_reset: datetime | None
+    _attr_native_precision: int | None
     _attr_native_unit_of_measurement: str | None
     _attr_native_value: StateType | date | datetime | Decimal = None
     _attr_options: list[str] | None
@@ -607,9 +161,12 @@ class SensorEntity(Entity):
     _attr_unit_of_measurement: None = (
         None  # Subclasses of SensorEntity should not set this
     )
+    _invalid_numeric_value_reported = False
+    _invalid_state_class_reported = False
     _invalid_unit_of_measurement_reported = False
     _last_reset_reported = False
-    _sensor_option_unit_of_measurement: str | None = None
+    _sensor_option_precision: int | None = None
+    _sensor_option_unit_of_measurement: str | None | UndefinedType = UNDEFINED
 
     @callback
     def add_to_platform_start(
@@ -786,6 +343,60 @@ class SensorEntity(Entity):
         """Return the value reported by the sensor."""
         return self._attr_native_value
 
+    @property
+    def native_precision(self) -> int | None:
+        """Return the number of digits after the decimal point for the sensor's state.
+
+        If native_precision is None, no rounding is done unless the sensor is subject
+        to unit conversion.
+
+        The display precision is influenced by unit conversion, a sensor which has
+        native_unit_of_measurement 'Wh' and is converted to 'kWh' will have its
+        native_precision increased by 3.
+        """
+        if hasattr(self, "_attr_native_precision"):
+            return self._attr_native_precision
+        if hasattr(self, "entity_description"):
+            return self.entity_description.native_precision
+        return None
+
+    @final
+    @property
+    def precision(self) -> int | None:
+        """Return the number of digits after the decimal point for the sensor's state.
+
+        This is the precision after unit conversion.
+        """
+        # Highest priority, for registered entities: precision set by user
+        if self._sensor_option_precision is not None:
+            return self._sensor_option_precision
+
+        # Second priority, native precision
+        if (precision := self.native_precision) is None:
+            return None
+
+        device_class = self.device_class
+        native_unit_of_measurement = self.native_unit_of_measurement
+        unit_of_measurement = self.unit_of_measurement
+
+        if (
+            native_unit_of_measurement != unit_of_measurement
+            and device_class in UNIT_CONVERTERS
+        ):
+            converter = UNIT_CONVERTERS[device_class]
+
+            # Scale the precision when converting to a larger or smaller unit
+            # For example 1.1 Wh should be rendered as 0.0011 kWh, not 0.0 kWh
+            ratio_log = log10(
+                converter.get_unit_ratio(
+                    native_unit_of_measurement, unit_of_measurement
+                )
+            )
+            ratio_log = floor(ratio_log) if ratio_log > 0 else ceil(ratio_log)
+            precision = max(0, precision + ratio_log)
+
+        return precision
+
     @property
     def native_unit_of_measurement(self) -> str | None:
         """Return the unit of measurement of the sensor, if any."""
@@ -806,12 +417,12 @@ class SensorEntity(Entity):
         For sensors without a `unique_id`, this takes precedence over legacy
         temperature conversion rules only.
 
-        For sensors with a `unique_id`, this is applied only if the unit is not set by the user,
-        and takes precedence over automatic device-class conversion rules.
+        For sensors with a `unique_id`, this is applied only if the unit is not set by
+        the user, and takes precedence over automatic device-class conversion rules.
 
         Note:
-            suggested_unit_of_measurement is stored in the entity registry the first time
-            the entity is seen, and then never updated.
+            suggested_unit_of_measurement is stored in the entity registry the first
+            time the entity is seen, and then never updated.
         """
         if hasattr(self, "_attr_suggested_unit_of_measurement"):
             return self._attr_suggested_unit_of_measurement
@@ -823,9 +434,9 @@ class SensorEntity(Entity):
     @property
     def unit_of_measurement(self) -> str | None:
         """Return the unit of measurement of the entity, after unit conversion."""
-        # Highest priority, for registered entities: unit set by user, with fallback to unit suggested
-        # by integration or secondary fallback to unit conversion rules
-        if self._sensor_option_unit_of_measurement:
+        # Highest priority, for registered entities: unit set by user,with fallback to
+        # unit suggested by integration or secondary fallback to unit conversion rules
+        if self._sensor_option_unit_of_measurement is not UNDEFINED:
             return self._sensor_option_unit_of_measurement
 
         # Second priority, for non registered entities: unit suggested by integration
@@ -837,7 +448,7 @@ class SensorEntity(Entity):
         native_unit_of_measurement = self.native_unit_of_measurement
 
         if (
-            self.device_class == DEVICE_CLASS_TEMPERATURE
+            self.device_class == SensorDeviceClass.TEMPERATURE
             and native_unit_of_measurement
             in {UnitOfTemperature.CELSIUS, UnitOfTemperature.FAHRENHEIT}
         ):
@@ -848,15 +459,68 @@ class SensorEntity(Entity):
 
     @final
     @property
-    def state(self) -> Any:
+    def state(self) -> Any:  # noqa: C901
         """Return the state of the sensor and perform unit conversions, if needed."""
         native_unit_of_measurement = self.native_unit_of_measurement
         unit_of_measurement = self.unit_of_measurement
         value = self.native_value
-        device_class = self.device_class
+        device_class: SensorDeviceClass | None = None
+        with suppress(ValueError):
+            # For the sake of validation, we can ignore custom device classes
+            # (customization and legacy style translations)
+            device_class = SensorDeviceClass(str(self.device_class))
+        state_class = self.state_class
+
+        # Sensors with device classes indicating a non-numeric value
+        # should not have a unit of measurement
+        if (
+            device_class
+            in {
+                SensorDeviceClass.DATE,
+                SensorDeviceClass.ENUM,
+                SensorDeviceClass.TIMESTAMP,
+            }
+            and unit_of_measurement
+        ):
+            raise ValueError(
+                f"Sensor {self.entity_id} has a unit of measurement and thus "
+                "indicating it has a numeric value; however, it has the "
+                f"non-numeric device class: {device_class}"
+            )
+
+        # Validate state class for sensors with a device class
+        if (
+            state_class
+            and not self._invalid_state_class_reported
+            and device_class
+            and (classes := DEVICE_CLASS_STATE_CLASSES.get(device_class)) is not None
+            and state_class not in classes
+        ):
+            self._invalid_state_class_reported = True
+            report_issue = self._suggest_report_issue()
+
+            # This should raise in Home Assistant Core 2023.6
+            _LOGGER.warning(
+                "Entity %s (%s) is using state class '%s' which "
+                "is impossible considering device class ('%s') it is using; "
+                "expected %s%s; "
+                "Please update your configuration if your entity is manually "
+                "configured, otherwise %s",
+                self.entity_id,
+                type(self),
+                state_class,
+                device_class,
+                "None or one of " if classes else "None",
+                ", ".join(f"'{value.value}'" for value in classes),
+                report_issue,
+            )
+
+        # Checks below only apply if there is a value
+        if value is None:
+            return None
 
         # Received a datetime
-        if value is not None and device_class == DEVICE_CLASS_TIMESTAMP:
+        if device_class == SensorDeviceClass.TIMESTAMP:
             try:
                 # We cast the value, to avoid using isinstance, but satisfy
                 # typechecking. The errors are guarded in this try.
@@ -878,7 +542,7 @@ class SensorEntity(Entity):
                 ) from err
 
         # Received a date value
-        if value is not None and device_class == DEVICE_CLASS_DATE:
+        if device_class == SensorDeviceClass.DATE:
             try:
                 # We cast the value, to avoid using isinstance, but satisfy
                 # typechecking. The errors are guarded in this try.
@@ -890,31 +554,8 @@ class SensorEntity(Entity):
                     f"but provides state {value}:{type(value)} resulting in '{err}'"
                 ) from err
 
-        # Sensors with device classes indicating a non-numeric value
-        # should not have a state class or unit of measurement
-        if device_class in {
-            SensorDeviceClass.DATE,
-            SensorDeviceClass.ENUM,
-            SensorDeviceClass.TIMESTAMP,
-        }:
-            if self.state_class:
-                raise ValueError(
-                    f"Sensor {self.entity_id} has a state class and thus indicating "
-                    "it has a numeric value; however, it has the non-numeric "
-                    f"device class: {device_class}"
-                )
-
-            if unit_of_measurement:
-                raise ValueError(
-                    f"Sensor {self.entity_id} has a unit of measurement and thus "
-                    "indicating it has a numeric value; however, it has the "
-                    f"non-numeric device class: {device_class}"
-                )
-
         # Enum checks
-        if value is not None and (
-            device_class == SensorDeviceClass.ENUM or self.options is not None
-        ):
+        if device_class == SensorDeviceClass.ENUM or self.options is not None:
             if device_class != SensorDeviceClass.ENUM:
                 reason = "is missing the enum device class"
                 if device_class is not None:
@@ -928,47 +569,103 @@ class SensorEntity(Entity):
                     f"Sensor {self.entity_id} provides state value '{value}', "
                     "which is not in the list of options provided"
                 )
+            return value
+
+        precision = self.precision
+
+        # If the sensor has neither a device class, a state class, a unit of measurement
+        # nor a precision then there are no further checks or conversions
+        if (
+            not device_class
+            and not state_class
+            and not unit_of_measurement
+            and precision is None
+        ):
+            return value
+
+        # From here on a numerical value is expected
+        numerical_value: int | float | Decimal
+        if not isinstance(value, (int, float, Decimal)):
+            try:
+                if isinstance(value, str) and "." not in value:
+                    numerical_value = int(value)
+                else:
+                    numerical_value = float(value)  # type:ignore[arg-type]
+            except (TypeError, ValueError) as err:
+                # Raise if precision is not None, for other cases log a warning
+                if precision is not None:
+                    raise ValueError(
+                        f"Sensor {self.entity_id} has device class {device_class}, "
+                        f"state class {state_class} unit {unit_of_measurement} and "
+                        f"precision {precision} thus indicating it has a numeric value;"
+                        f" however, it has the non-numeric value: {value} "
+                        f"({type(value)})"
+                    ) from err
+                # This should raise in Home Assistant Core 2023.4
+                if not self._invalid_numeric_value_reported:
+                    self._invalid_numeric_value_reported = True
+                    report_issue = self._suggest_report_issue()
+                    _LOGGER.warning(
+                        "Sensor %s has device class %s, state class %s and unit %s "
+                        "thus indicating it has a numeric value; however, it has the "
+                        "non-numeric value: %s (%s); Please update your configuration "
+                        "if your entity is manually configured, otherwise %s",
+                        self.entity_id,
+                        device_class,
+                        state_class,
+                        unit_of_measurement,
+                        value,
+                        type(value),
+                        report_issue,
+                    )
+                return value
+        else:
+            numerical_value = value
 
         if (
-            value is not None
-            and native_unit_of_measurement != unit_of_measurement
+            native_unit_of_measurement != unit_of_measurement
             and device_class in UNIT_CONVERTERS
         ):
-            assert unit_of_measurement
-            assert native_unit_of_measurement
+            # Unit conversion needed
             converter = UNIT_CONVERTERS[device_class]
 
-            value_s = str(value)
-            prec = len(value_s) - value_s.index(".") - 1 if "." in value_s else 0
-
-            # Scale the precision when converting to a larger unit
-            # For example 1.1 Wh should be rendered as 0.0011 kWh, not 0.0 kWh
-            ratio_log = max(
-                0,
-                log10(
-                    converter.get_unit_ratio(
-                        native_unit_of_measurement, unit_of_measurement
-                    )
-                ),
-            )
-            prec = prec + floor(ratio_log)
-
-            # Suppress ValueError (Could not convert sensor_value to float)
-            with suppress(ValueError):
-                value_f = float(value)  # type: ignore[arg-type]
-                value_f_new = converter.convert(
-                    value_f,
-                    native_unit_of_measurement,
-                    unit_of_measurement,
+            if precision is None:
+                # Deduce the precision by finding the decimal point, if any
+                value_s = str(value)
+                precision = (
+                    len(value_s) - value_s.index(".") - 1 if "." in value_s else 0
                 )
 
-                # Round to the wanted precision
-                value = round(value_f_new) if prec == 0 else round(value_f_new, prec)
+                # Scale the precision when converting to a larger unit
+                # For example 1.1 Wh should be rendered as 0.0011 kWh, not 0.0 kWh
+                ratio_log = max(
+                    0,
+                    log10(
+                        converter.get_unit_ratio(
+                            native_unit_of_measurement, unit_of_measurement
+                        )
+                    ),
+                )
+                precision = precision + floor(ratio_log)
+
+            converted_numerical_value = converter.convert(
+                float(numerical_value),
+                native_unit_of_measurement,
+                unit_of_measurement,
+            )
+            value = f"{converted_numerical_value:.{precision}f}"
+            # This can be replaced with adding the z option when we drop support for
+            # Python 3.10
+            value = NEGATIVE_ZERO_PATTERN.sub(r"\1", value)
+        elif precision is not None:
+            value = f"{numerical_value:.{precision}f}"
+            # This can be replaced with adding the z option when we drop support for
+            # Python 3.10
+            value = NEGATIVE_ZERO_PATTERN.sub(r"\1", value)
 
         # Validate unit of measurement used for sensors with a device class
         if (
             not self._invalid_unit_of_measurement_reported
-            and value is not None
             and device_class
             and (units := DEVICE_CLASS_UNITS.get(device_class)) is not None
             and native_unit_of_measurement not in units
@@ -981,6 +678,7 @@ class SensorEntity(Entity):
                 (
                     "Entity %s (%s) is using native unit of measurement '%s' which "
                     "is not a valid unit for the device class ('%s') it is using; "
+                    "expected one of %s; "
                     "Please update your configuration if your entity is manually "
                     "configured, otherwise %s"
                 ),
@@ -988,6 +686,7 @@ class SensorEntity(Entity):
                 type(self),
                 native_unit_of_measurement,
                 device_class,
+                [str(unit) if unit else "no unit of measurement" for unit in units],
                 report_issue,
             )
 
@@ -1004,28 +703,41 @@ class SensorEntity(Entity):
 
         return super().__repr__()
 
-    def _custom_unit_or_none(self, primary_key: str, secondary_key: str) -> str | None:
-        """Return a custom unit, or None if it's not compatible with the native unit."""
+    def _custom_precision_or_none(self) -> int | None:
+        """Return a custom precisions or None if not set."""
+        assert self.registry_entry
+        if (sensor_options := self.registry_entry.options.get(DOMAIN)) and (
+            precision := sensor_options.get("precision")
+        ) is not None:
+            return int(precision)
+        return None
+
+    def _custom_unit_or_undef(
+        self, primary_key: str, secondary_key: str
+    ) -> str | None | UndefinedType:
+        """Return a custom unit, or UNDEFINED if not compatible with the native unit."""
         assert self.registry_entry
         if (
             (sensor_options := self.registry_entry.options.get(primary_key))
-            and (custom_unit := sensor_options.get(secondary_key))
+            and secondary_key in sensor_options
             and (device_class := self.device_class) in UNIT_CONVERTERS
             and self.native_unit_of_measurement
             in UNIT_CONVERTERS[device_class].VALID_UNITS
-            and custom_unit in UNIT_CONVERTERS[device_class].VALID_UNITS
+            and (custom_unit := sensor_options[secondary_key])
+            in UNIT_CONVERTERS[device_class].VALID_UNITS
         ):
             return cast(str, custom_unit)
-        return None
+        return UNDEFINED
 
     @callback
     def async_registry_entry_updated(self) -> None:
         """Run when the entity registry entry has been updated."""
-        self._sensor_option_unit_of_measurement = self._custom_unit_or_none(
+        self._sensor_option_precision = self._custom_precision_or_none()
+        self._sensor_option_unit_of_measurement = self._custom_unit_or_undef(
             DOMAIN, CONF_UNIT_OF_MEASUREMENT
         )
-        if not self._sensor_option_unit_of_measurement:
-            self._sensor_option_unit_of_measurement = self._custom_unit_or_none(
+        if self._sensor_option_unit_of_measurement is UNDEFINED:
+            self._sensor_option_unit_of_measurement = self._custom_unit_or_undef(
                 f"{DOMAIN}.private", "suggested_unit_of_measurement"
             )
 
