@@ -3,8 +3,9 @@ from __future__ import annotations
 
 import datetime
 import logging
-from typing import Any
+from typing import Any, cast
 
+from soco.alarms import Alarm
 from soco.exceptions import SoCoSlaveException, SoCoUPnPException
 
 from homeassistant.components.switch import ENTITY_ID_FORMAT, SwitchEntity
@@ -15,6 +16,7 @@ from homeassistant.helpers import device_registry as dr, entity_registry as er
 from homeassistant.helpers.dispatcher import async_dispatcher_connect
 from homeassistant.helpers.entity import EntityCategory
 from homeassistant.helpers.entity_platform import AddEntitiesCallback
+from homeassistant.helpers.event import async_track_time_change
 
 from .const import (
     DATA_SONOS,
@@ -90,6 +92,8 @@ FEATURE_ICONS = {
     ATTR_TOUCH_CONTROLS: "mdi:gesture-tap",
 }
 
+WEEKEND_DAYS = (0, 6)
+
 
 async def async_setup_entry(
     hass: HomeAssistant,
@@ -183,14 +187,14 @@ class SonosSwitchEntity(SonosPollingEntity, SwitchEntity):
     def is_on(self) -> bool:
         """Return True if entity is on."""
         if self.needs_coordinator and not self.speaker.is_coordinator:
-            return getattr(self.speaker.coordinator, self.feature_type)
-        return getattr(self.speaker, self.feature_type)
+            return cast(bool, getattr(self.speaker.coordinator, self.feature_type))
+        return cast(bool, getattr(self.speaker, self.feature_type))
 
-    def turn_on(self, **kwargs) -> None:
+    def turn_on(self, **kwargs: Any) -> None:
         """Turn the entity on."""
         self.send_command(True)
 
-    def turn_off(self, **kwargs) -> None:
+    def turn_off(self, **kwargs: Any) -> None:
         """Turn the entity off."""
         self.send_command(False)
 
@@ -232,22 +236,36 @@ class SonosAlarmEntity(SonosEntity, SwitchEntity):
             )
         )
 
+        async def async_write_state_daily(now: datetime.datetime) -> None:
+            """Update alarm state attributes each calendar day."""
+            _LOGGER.debug("Updating state attributes for %s", self.name)
+            self.async_write_ha_state()
+
+        self.async_on_remove(
+            async_track_time_change(
+                self.hass, async_write_state_daily, hour=0, minute=0, second=0
+            )
+        )
+
     @property
-    def alarm(self):
+    def alarm(self) -> Alarm:
         """Return the alarm instance."""
         return self.hass.data[DATA_SONOS].alarms[self.household_id].get(self.alarm_id)
 
     @property
     def name(self) -> str:
         """Return the name of the sensor."""
-        return f"{self.alarm.recurrence.capitalize()} alarm {str(self.alarm.start_time)[:5]}"
+        return (
+            f"{self.alarm.recurrence.capitalize()} alarm"
+            f" {str(self.alarm.start_time)[:5]}"
+        )
 
     async def _async_fallback_poll(self) -> None:
         """Call the central alarm polling method."""
         await self.hass.data[DATA_SONOS].alarms[self.household_id].async_poll()
 
     @callback
-    def async_check_if_available(self):
+    def async_check_if_available(self) -> bool:
         """Check if alarm exists and remove alarm entity if not available."""
         if self.alarm:
             return True
@@ -279,7 +297,7 @@ class SonosAlarmEntity(SonosEntity, SwitchEntity):
         self.async_write_ha_state()
 
     @callback
-    def _async_update_device(self):
+    def _async_update_device(self) -> None:
         """Update the device, since this alarm moved to a different player."""
         device_registry = dr.async_get(self.hass)
         entity_registry = er.async_get(self.hass)
@@ -288,31 +306,27 @@ class SonosAlarmEntity(SonosEntity, SwitchEntity):
         if entity is None:
             raise RuntimeError("Alarm has been deleted by accident.")
 
-        entry_id = entity.config_entry_id
-
         new_device = device_registry.async_get_or_create(
-            config_entry_id=entry_id,
+            config_entry_id=cast(str, entity.config_entry_id),
             identifiers={(SONOS_DOMAIN, self.soco.uid)},
             connections={(dr.CONNECTION_NETWORK_MAC, self.speaker.mac_address)},
         )
-        if not entity_registry.async_get(self.entity_id).device_id == new_device.id:
+        if (
+            device := entity_registry.async_get(self.entity_id)
+        ) and device.device_id != new_device.id:
             _LOGGER.debug("%s is moving to %s", self.entity_id, new_device.name)
-            # pylint: disable=protected-access
-            entity_registry._async_update_entity(
-                self.entity_id, device_id=new_device.id
-            )
+            entity_registry.async_update_entity(self.entity_id, device_id=new_device.id)
 
     @property
-    def _is_today(self):
+    def _is_today(self) -> bool:
+        """Return whether this alarm is scheduled for today."""
         recurrence = self.alarm.recurrence
-        timestr = int(datetime.datetime.today().strftime("%w"))
+        daynum = int(datetime.datetime.today().strftime("%w"))
         return (
-            bool(recurrence[:2] == "ON" and str(timestr) in recurrence)
-            or bool(recurrence == "DAILY")
-            or bool(recurrence == "WEEKDAYS" and int(timestr) not in [0, 7])
-            or bool(recurrence == "ONCE")
-            or bool(recurrence == "WEEKDAYS" and int(timestr) not in [0, 7])
-            or bool(recurrence == "WEEKENDS" and int(timestr) not in range(1, 7))
+            recurrence in ("DAILY", "ONCE")
+            or (recurrence == "WEEKENDS" and daynum in WEEKEND_DAYS)
+            or (recurrence == "WEEKDAYS" and daynum not in WEEKEND_DAYS)
+            or (recurrence.startswith("ON_") and str(daynum) in recurrence)
         )
 
     @property
@@ -321,12 +335,12 @@ class SonosAlarmEntity(SonosEntity, SwitchEntity):
         return (self.alarm is not None) and self.speaker.available
 
     @property
-    def is_on(self):
+    def is_on(self) -> bool:
         """Return state of Sonos alarm switch."""
         return self.alarm.enabled
 
     @property
-    def extra_state_attributes(self):
+    def extra_state_attributes(self) -> dict[str, Any]:
         """Return attributes of Sonos alarm switch."""
         return {
             ATTR_ID: str(self.alarm_id),
@@ -413,7 +427,10 @@ def async_migrate_speech_enhancement_entity_unique_id(
 
     if len(speech_enhancement_entries) > 1:
         _LOGGER.warning(
-            "Migration of Speech Enhancement switches on %s failed, manual cleanup required: %s",
+            (
+                "Migration of Speech Enhancement switches on %s failed,"
+                " manual cleanup required: %s"
+            ),
             speaker.zone_name,
             [e.entity_id for e in speech_enhancement_entries],
         )
