@@ -4,7 +4,7 @@ from __future__ import annotations
 from collections.abc import Callable, Generator, Iterable
 from datetime import timedelta
 import logging
-from typing import Any, Union, cast
+from typing import Any, cast
 
 from pyunifiprotect import ProtectApiClient
 from pyunifiprotect.data import (
@@ -39,7 +39,7 @@ from .const import (
 from .utils import async_dispatch_id as _ufpd, async_get_devices_by_type
 
 _LOGGER = logging.getLogger(__name__)
-ProtectDeviceType = Union[ProtectAdoptableDeviceModel, NVR]
+ProtectDeviceType = ProtectAdoptableDeviceModel | NVR
 
 
 @callback
