@@ -9,6 +9,8 @@ import inspect
 import logging
 from typing import Any, Final, TypedDict, final
 
+from typing_extensions import Required
+
 from homeassistant.config_entries import ConfigEntry
 from homeassistant.const import (
     PRECISION_HALVES,
@@ -155,11 +157,12 @@ def round_temperature(temperature: float | None, precision: float) -> float | No
 class Forecast(TypedDict, total=False):
     """Typed weather forecast dict.
 
-    All attributes are in native units and old attributes kept for backwards compatibility.
+    All attributes are in native units and old attributes kept
+    for backwards compatibility.
     """
 
     condition: str | None
-    datetime: str
+    datetime: Required[str]
     precipitation_probability: int | None
     native_precipitation: float | None
     precipitation: None
@@ -620,7 +623,10 @@ class WeatherEntity(Entity):
     @final
     @property
     def state_attributes(self) -> dict[str, Any]:
-        """Return the state attributes, converted from native units to user-configured units."""
+        """Return the state attributes, converted.
+
+        Attributes are configured from native units to user-configured units.
+        """
         data: dict[str, Any] = {}
 
         precision = self.precision
