@@ -2,6 +2,7 @@
 from __future__ import annotations
 
 from dataclasses import dataclass, field
+import logging
 from typing import NamedTuple
 
 from miio.fan_common import LedBrightness as FanLedBrightness
@@ -52,6 +53,7 @@ from .const import (
     MODEL_AIRPURIFIER_M1,
     MODEL_AIRPURIFIER_M2,
     MODEL_AIRPURIFIER_PROH,
+    MODEL_AIRPURIFIER_ZA1,
     MODEL_FAN_SA1,
     MODEL_FAN_V2,
     MODEL_FAN_V3,
@@ -66,6 +68,9 @@ ATTR_LED_BRIGHTNESS = "led_brightness"
 ATTR_PTC_LEVEL = "ptc_level"
 
 
+_LOGGER = logging.getLogger(__name__)
+
+
 @dataclass
 class XiaomiMiioSelectDescription(SelectEntityDescription):
     """A class that describes select entities."""
@@ -109,6 +114,9 @@ MODEL_TO_ATTR_MAP: dict[str, list] = {
     MODEL_AIRPURIFIER_3: [
         AttributeEnumMapping(ATTR_LED_BRIGHTNESS, AirpurifierMiotLedBrightness)
     ],
+    MODEL_AIRPURIFIER_ZA1: [
+        AttributeEnumMapping(ATTR_LED_BRIGHTNESS, AirpurifierMiotLedBrightness)
+    ],
     MODEL_AIRPURIFIER_3H: [
         AttributeEnumMapping(ATTR_LED_BRIGHTNESS, AirpurifierMiotLedBrightness)
     ],
@@ -148,7 +156,7 @@ SELECTOR_TYPES = (
         set_method="set_display_orientation",
         set_method_error_message="Setting the display orientation failed.",
         icon="mdi:tablet",
-        device_class="xiaomi_miio__display_orientation",
+        translation_key="display_orientation",
         options=["forward", "left", "right"],
         entity_category=EntityCategory.CONFIG,
     ),
@@ -159,7 +167,7 @@ SELECTOR_TYPES = (
         set_method="set_led_brightness",
         set_method_error_message="Setting the led brightness failed.",
         icon="mdi:brightness-6",
-        device_class="xiaomi_miio__led_brightness",
+        translation_key="led_brightness",
         options=["bright", "dim", "off"],
         entity_category=EntityCategory.CONFIG,
     ),
@@ -170,7 +178,7 @@ SELECTOR_TYPES = (
         set_method="set_ptc_level",
         set_method_error_message="Setting the ptc level failed.",
         icon="mdi:fire-circle",
-        device_class="xiaomi_miio__ptc_level",
+        translation_key="ptc_level",
         options=["low", "medium", "high"],
         entity_category=EntityCategory.CONFIG,
     ),
@@ -248,11 +256,17 @@ class XiaomiGenericSelector(XiaomiSelector):
     @callback
     def _handle_coordinator_update(self):
         """Fetch state from the device."""
-        attr = self._enum_class(
-            self._extract_value_from_attribute(
+        try:
+            value = self._extract_value_from_attribute(
                 self.coordinator.data, self.entity_description.attr_name
             )
-        )
+            attr = self._enum_class(value)
+        except ValueError:  # if the value does not exist in
+            _LOGGER.debug(
+                "Value '%s' does not exist in enum %s", value, self._enum_class
+            )
+            attr = None
+
         if attr is not None:
             self._current_attr = attr
             self.async_write_ha_state()
