@@ -2,10 +2,6 @@
 
 import voluptuous as vol
 
-from homeassistant.components.automation import (
-    AutomationActionType,
-    AutomationTriggerInfo,
-)
 from homeassistant.components.device_automation import DEVICE_TRIGGER_BASE_SCHEMA
 from homeassistant.components.device_automation.exceptions import (
     InvalidDeviceAutomationConfig,
@@ -14,10 +10,11 @@ from homeassistant.components.homeassistant.triggers import event as event_trigg
 from homeassistant.const import CONF_DEVICE_ID, CONF_DOMAIN, CONF_PLATFORM, CONF_TYPE
 from homeassistant.core import CALLBACK_TYPE, HomeAssistant
 from homeassistant.exceptions import HomeAssistantError, IntegrationError
+from homeassistant.helpers.trigger import TriggerActionType, TriggerInfo
 from homeassistant.helpers.typing import ConfigType
 
 from . import DOMAIN as ZHA_DOMAIN
-from .core.const import DATA_ZHA, ZHA_DEVICES_LOADED_EVENT, ZHA_EVENT
+from .core.const import ZHA_EVENT
 from .core.helpers import async_get_zha_device
 
 CONF_SUBTYPE = "subtype"
@@ -35,18 +32,16 @@ async def async_validate_trigger_config(
     """Validate config."""
     config = TRIGGER_SCHEMA(config)
 
-    if ZHA_DOMAIN in hass.config.components:
-        await hass.data[DATA_ZHA][ZHA_DEVICES_LOADED_EVENT].wait()
-        trigger = (config[CONF_TYPE], config[CONF_SUBTYPE])
-        try:
-            zha_device = async_get_zha_device(hass, config[CONF_DEVICE_ID])
-        except (KeyError, AttributeError, IntegrationError) as err:
-            raise InvalidDeviceAutomationConfig from err
-        if (
-            zha_device.device_automation_triggers is None
-            or trigger not in zha_device.device_automation_triggers
-        ):
-            raise InvalidDeviceAutomationConfig
+    trigger = (config[CONF_TYPE], config[CONF_SUBTYPE])
+    try:
+        zha_device = async_get_zha_device(hass, config[CONF_DEVICE_ID])
+    except (KeyError, AttributeError, IntegrationError) as err:
+        raise InvalidDeviceAutomationConfig from err
+    if (
+        zha_device.device_automation_triggers is None
+        or trigger not in zha_device.device_automation_triggers
+    ):
+        raise InvalidDeviceAutomationConfig(f"device does not have trigger {trigger}")
 
     return config
 
@@ -54,8 +49,8 @@ async def async_validate_trigger_config(
 async def async_attach_trigger(
     hass: HomeAssistant,
     config: ConfigType,
-    action: AutomationActionType,
-    automation_info: AutomationTriggerInfo,
+    action: TriggerActionType,
+    trigger_info: TriggerInfo,
 ) -> CALLBACK_TYPE:
     """Listen for state changes based on configuration."""
     trigger_key: tuple[str, str] = (config[CONF_TYPE], config[CONF_SUBTYPE])
@@ -79,7 +74,7 @@ async def async_attach_trigger(
 
     event_config = event_trigger.TRIGGER_SCHEMA(event_config)
     return await event_trigger.async_attach_trigger(
-        hass, event_config, action, automation_info, platform_type="device"
+        hass, event_config, action, trigger_info, platform_type="device"
     )
 
 
