@@ -18,6 +18,7 @@ from zigpy.zcl.foundation import Status
 from homeassistant.components import light
 from homeassistant.components.light import (
     ColorMode,
+    LightEntityFeature,
     brightness_supported,
     filter_supported_color_modes,
 )
@@ -28,7 +29,7 @@ from homeassistant.const import (
     STATE_UNAVAILABLE,
     Platform,
 )
-from homeassistant.core import CALLBACK_TYPE, Event, HomeAssistant, State, callback
+from homeassistant.core import CALLBACK_TYPE, HomeAssistant, State, callback
 from homeassistant.helpers.debounce import Debouncer
 from homeassistant.helpers.dispatcher import (
     async_dispatcher_connect,
@@ -46,6 +47,7 @@ from .core.const import (
     CONF_DEFAULT_LIGHT_TRANSITION,
     CONF_ENABLE_ENHANCED_LIGHT_TRANSITION,
     CONF_ENABLE_LIGHT_TRANSITIONING_FLAG,
+    CONF_GROUP_MEMBERS_ASSUME_STATE,
     DATA_ZHA,
     SIGNAL_ADD_ENTITIES,
     SIGNAL_ATTR_UPDATED,
@@ -66,6 +68,7 @@ DEFAULT_EXTRA_TRANSITION_DELAY_SHORT = 0.25
 DEFAULT_EXTRA_TRANSITION_DELAY_LONG = 2.0
 DEFAULT_LONG_TRANSITION_TIME = 10
 DEFAULT_MIN_BRIGHTNESS = 2
+ASSUME_UPDATE_GROUP_FROM_CHILD_DELAY = 0.05
 
 FLASH_EFFECTS = {
     light.FLASH_SHORT: Identify.EffectIdentifier.Blink,
@@ -78,6 +81,7 @@ PARALLEL_UPDATES = 0
 SIGNAL_LIGHT_GROUP_STATE_CHANGED = "zha_light_group_state_changed"
 SIGNAL_LIGHT_GROUP_TRANSITION_START = "zha_light_group_transition_start"
 SIGNAL_LIGHT_GROUP_TRANSITION_FINISHED = "zha_light_group_transition_finished"
+SIGNAL_LIGHT_GROUP_ASSUME_GROUP_STATE = "zha_light_group_assume_group_state"
 DEFAULT_MIN_TRANSITION_MANUFACTURERS = {"sengled"}
 
 COLOR_MODES_GROUP_LIGHT = {ColorMode.COLOR_TEMP, ColorMode.XY}
@@ -118,7 +122,7 @@ class BaseLight(LogMixin, light.LightEntity):
         super().__init__(*args, **kwargs)
         self._attr_min_mireds: int | None = 153
         self._attr_max_mireds: int | None = 500
-        self._attr_color_mode = ColorMode.UNKNOWN  # Set by sub classes
+        self._attr_color_mode = ColorMode.UNKNOWN  # Set by subclasses
         self._attr_supported_features: int = 0
         self._attr_state: bool | None
         self._off_with_transition: bool = False
@@ -131,7 +135,8 @@ class BaseLight(LogMixin, light.LightEntity):
         self._level_channel = None
         self._color_channel = None
         self._identify_channel = None
-        self._transitioning: bool = False
+        self._transitioning_individual: bool = False
+        self._transitioning_group: bool = False
         self._transition_listener: Callable[[], None] | None = None
 
     @property
@@ -158,7 +163,7 @@ class BaseLight(LogMixin, light.LightEntity):
         on at `on_level` Zigbee attribute value, regardless of the last set
         level
         """
-        if self._transitioning:
+        if self.is_transitioning:
             self.debug(
                 "received level %s while transitioning - skipping update",
                 value,
@@ -183,6 +188,12 @@ class BaseLight(LogMixin, light.LightEntity):
         xy_color = kwargs.get(light.ATTR_XY_COLOR)
         hs_color = kwargs.get(light.ATTR_HS_COLOR)
 
+        execute_if_off_supported = (
+            self._GROUP_SUPPORTS_EXECUTE_IF_OFF
+            if isinstance(self, LightGroup)
+            else self._color_channel and self._color_channel.execute_if_off_supported
+        )
+
         set_transition_flag = (
             brightness_supported(self._attr_supported_color_modes)
             or temperature is not None
@@ -249,6 +260,7 @@ class BaseLight(LogMixin, light.LightEntity):
                 )
             )
             and brightness_supported(self._attr_supported_color_modes)
+            and not execute_if_off_supported
         )
 
         if (
@@ -283,6 +295,23 @@ class BaseLight(LogMixin, light.LightEntity):
             # Currently only setting it to "on", as the correct level state will be set at the second move_to_level call
             self._attr_state = True
 
+        if execute_if_off_supported:
+            self.debug("handling color commands before turning on/level")
+            if not await self.async_handle_color_commands(
+                temperature,
+                duration,  # duration is ignored by lights when off
+                hs_color,
+                xy_color,
+                new_color_provided_while_off,
+                t_log,
+            ):
+                # Color calls before on/level calls failed,
+                # so if the transitioning delay isn't running from a previous call, the flag can be unset immediately
+                if set_transition_flag and not self._transition_listener:
+                    self.async_transition_complete()
+                self.debug("turned on: %s", t_log)
+                return
+
         if (
             (brightness is not None or transition)
             and not new_color_provided_while_off
@@ -321,18 +350,20 @@ class BaseLight(LogMixin, light.LightEntity):
                 return
             self._attr_state = True
 
-        if not await self.async_handle_color_commands(
-            temperature,
-            duration,
-            hs_color,
-            xy_color,
-            new_color_provided_while_off,
-            t_log,
-        ):
-            # Color calls failed, but as brightness may still transition, we start the timer to unset the flag
-            self.async_transition_start_timer(transition_time)
-            self.debug("turned on: %s", t_log)
-            return
+        if not execute_if_off_supported:
+            self.debug("handling color commands after turning on/level")
+            if not await self.async_handle_color_commands(
+                temperature,
+                duration,
+                hs_color,
+                xy_color,
+                new_color_provided_while_off,
+                t_log,
+            ):
+                # Color calls failed, but as brightness may still transition, we start the timer to unset the flag
+                self.async_transition_start_timer(transition_time)
+                self.debug("turned on: %s", t_log)
+                return
 
         if new_color_provided_while_off:
             # The light is has the correct color, so we can now transition it to the correct brightness level.
@@ -406,7 +437,7 @@ class BaseLight(LogMixin, light.LightEntity):
         if self._zha_config_enable_light_transitioning_flag:
             self.async_transition_set_flag()
 
-        # is not none looks odd here but it will override built in bulb transition times if we pass 0 in here
+        # is not none looks odd here, but it will override built in bulb transition times if we pass 0 in here
         if transition is not None and supports_level:
             result = await self._level_channel.move_to_level_with_on_off(
                 level=0,
@@ -423,10 +454,15 @@ class BaseLight(LogMixin, light.LightEntity):
             return
         self._attr_state = False
 
-        if supports_level:
-            # store current brightness so that the next turn_on uses it.
-            self._off_with_transition = transition is not None
+        if supports_level and not self._off_with_transition:
+            # store current brightness so that the next turn_on uses it:
+            # when using "enhanced turn on"
             self._off_brightness = self._attr_brightness
+            if transition is not None:
+                # save for when calling turn_on without a brightness:
+                # current_level is set to 1 after transitioning to level 0, needed for correct state with light groups
+                self._attr_brightness = 1
+                self._off_with_transition = transition is not None
 
         self.async_write_ha_state()
 
@@ -502,11 +538,17 @@ class BaseLight(LogMixin, light.LightEntity):
 
         return True
 
+    @property
+    def is_transitioning(self) -> bool:
+        """Return if the light is transitioning."""
+        return self._transitioning_individual or self._transitioning_group
+
     @callback
     def async_transition_set_flag(self) -> None:
         """Set _transitioning to True."""
         self.debug("setting transitioning flag to True")
-        self._transitioning = True
+        self._transitioning_individual = True
+        self._transitioning_group = False
         if isinstance(self, LightGroup):
             async_dispatcher_send(
                 self.hass,
@@ -518,7 +560,7 @@ class BaseLight(LogMixin, light.LightEntity):
 
     @callback
     def async_transition_start_timer(self, transition_time) -> None:
-        """Start a timer to unset _transitioning after transition_time if necessary."""
+        """Start a timer to unset _transitioning_individual after transition_time if necessary."""
         if not transition_time:
             return
         # For longer transitions, we want to extend the timer a bit more
@@ -533,9 +575,9 @@ class BaseLight(LogMixin, light.LightEntity):
 
     @callback
     def async_transition_complete(self, _=None) -> None:
-        """Set _transitioning to False and write HA state."""
+        """Set _transitioning_individual to False and write HA state."""
         self.debug("transition complete - future attribute reports will write HA state")
-        self._transitioning = False
+        self._transitioning_individual = False
         if self._transition_listener:
             self._transition_listener()
             self._transition_listener = None
@@ -670,7 +712,7 @@ class Light(BaseLight, ZhaEntity):
     @callback
     def async_set_state(self, attr_id, attr_name, value):
         """Set the state."""
-        if self._transitioning:
+        if self.is_transitioning:
             self.debug(
                 "received onoff %s while transitioning - skipping update",
                 value,
@@ -710,7 +752,7 @@ class Light(BaseLight, ZhaEntity):
                 self.debug(
                     "group transition started - setting member transitioning flag"
                 )
-                self._transitioning = True
+                self._transitioning_group = True
 
         self.async_accept_signal(
             None,
@@ -726,7 +768,7 @@ class Light(BaseLight, ZhaEntity):
                 self.debug(
                     "group transition completed - unsetting member transitioning flag"
                 )
-                self._transitioning = False
+                self._transitioning_group = False
 
         self.async_accept_signal(
             None,
@@ -735,6 +777,13 @@ class Light(BaseLight, ZhaEntity):
             signal_override=True,
         )
 
+        self.async_accept_signal(
+            None,
+            SIGNAL_LIGHT_GROUP_ASSUME_GROUP_STATE,
+            self._assume_group_state,
+            signal_override=True,
+        )
+
     async def async_will_remove_from_hass(self) -> None:
         """Disconnect entity object when removed."""
         assert self._cancel_refresh_handle
@@ -767,18 +816,31 @@ class Light(BaseLight, ZhaEntity):
         if not self._attr_available:
             return
         self.debug("polling current state")
+
         if self._on_off_channel:
             state = await self._on_off_channel.get_attribute_value(
                 "on_off", from_cache=False
             )
+            # check if transition started whilst waiting for polled state
+            if self.is_transitioning:
+                return
+
             if state is not None:
                 self._attr_state = state
+                if state:  # reset "off with transition" flag if the light is on
+                    self._off_with_transition = False
+                    self._off_brightness = None
+
         if self._level_channel:
             level = await self._level_channel.get_attribute_value(
                 "current_level", from_cache=False
             )
+            # check if transition started whilst waiting for polled state
+            if self.is_transitioning:
+                return
             if level is not None:
                 self._attr_brightness = level
+
         if self._color_channel:
             attributes = [
                 "color_mode",
@@ -807,6 +869,11 @@ class Light(BaseLight, ZhaEntity):
                 attributes, from_cache=False, only_cache=False
             )
 
+            # although rare, a transition might have been started while we were waiting for the polled attributes,
+            # so abort if we are transitioning, as that state will not be accurate
+            if self.is_transitioning:
+                return
+
             if (color_mode := results.get("color_mode")) is not None:
                 if color_mode == Color.ColorMode.Color_temperature:
                     self._attr_color_mode = ColorMode.COLOR_TEMP
@@ -852,14 +919,14 @@ class Light(BaseLight, ZhaEntity):
 
     async def async_update(self) -> None:
         """Update to the latest state."""
-        if self._transitioning:
+        if self.is_transitioning:
             self.debug("skipping async_update while transitioning")
             return
         await self.async_get_state()
 
     async def _refresh(self, time):
         """Call async_get_state at an interval."""
-        if self._transitioning:
+        if self.is_transitioning:
             self.debug("skipping _refresh while transitioning")
             return
         await self.async_get_state()
@@ -868,12 +935,71 @@ class Light(BaseLight, ZhaEntity):
     async def _maybe_force_refresh(self, signal):
         """Force update the state if the signal contains the entity id for this entity."""
         if self.entity_id in signal["entity_ids"]:
-            if self._transitioning:
+            if self.is_transitioning:
                 self.debug("skipping _maybe_force_refresh while transitioning")
                 return
             await self.async_get_state()
             self.async_write_ha_state()
 
+    @callback
+    def _assume_group_state(self, signal, update_params) -> None:
+        """Handle an assume group state event from a group."""
+        if self.entity_id in signal["entity_ids"] and self._attr_available:
+            self.debug("member assuming group state with: %s", update_params)
+
+            state = update_params["state"]
+            brightness = update_params.get(light.ATTR_BRIGHTNESS)
+            color_mode = update_params.get(light.ATTR_COLOR_MODE)
+            color_temp = update_params.get(light.ATTR_COLOR_TEMP)
+            xy_color = update_params.get(light.ATTR_XY_COLOR)
+            hs_color = update_params.get(light.ATTR_HS_COLOR)
+            effect = update_params.get(light.ATTR_EFFECT)
+
+            supported_modes = self._attr_supported_color_modes
+
+            # unset "off brightness" and "off with transition" if group turned on this light
+            if state and not self._attr_state:
+                self._off_with_transition = False
+                self._off_brightness = None
+
+            # set "off brightness" and "off with transition" if group turned off this light
+            elif (
+                not state  # group is turning the light off
+                and self._attr_state  # check the light was not already off (to not override _off_with_transition)
+                and brightness_supported(supported_modes)
+            ):
+                # use individual brightness, instead of possibly averaged brightness from group
+                self._off_brightness = self._attr_brightness
+                self._off_with_transition = update_params["off_with_transition"]
+
+            # Note: If individual lights have off_with_transition set, but not the group,
+            # and the group is then turned on without a level, individual lights might fall back to brightness level 1.
+            # Since all lights might need different brightness levels to be turned on, we can't use one group call.
+            # And making individual calls when turning on a ZHA group would cause a lot of traffic.
+            # In this case, turn_on should either just be called with a level or individual turn_on calls can be used.
+
+            # state is always set (light.turn_on/light.turn_off)
+            self._attr_state = state
+
+            # before assuming a group state attribute, check if the attribute was actually set in that call
+            if brightness is not None and brightness_supported(supported_modes):
+                self._attr_brightness = brightness
+            if color_mode is not None and color_mode in supported_modes:
+                self._attr_color_mode = color_mode
+            if color_temp is not None and ColorMode.COLOR_TEMP in supported_modes:
+                self._attr_color_temp = color_temp
+            if xy_color is not None and ColorMode.XY in supported_modes:
+                self._attr_xy_color = xy_color
+            if hs_color is not None and ColorMode.HS in supported_modes:
+                self._attr_hs_color = hs_color
+            # the effect is always deactivated in async_turn_on if not provided
+            if effect is None:
+                self._attr_effect = None
+            elif self._attr_effect_list and effect in self._attr_effect_list:
+                self._attr_effect = effect
+
+            self.async_write_ha_state()
+
 
 @STRICT_MATCH(
     channel_names=CHANNEL_ON_OFF,
@@ -923,6 +1049,20 @@ class LightGroup(BaseLight, ZhaGroupEntity):
         """Initialize a light group."""
         super().__init__(entity_ids, unique_id, group_id, zha_device, **kwargs)
         group = self.zha_device.gateway.get_group(self._group_id)
+
+        self._GROUP_SUPPORTS_EXECUTE_IF_OFF = True  # pylint: disable=invalid-name
+        # Check all group members to see if they support execute_if_off.
+        # If at least one member has a color cluster and doesn't support it, it's not used.
+        for member in group.members:
+            for pool in member.device.channels.pools:
+                for channel in pool.all_channels.values():
+                    if (
+                        channel.name == CHANNEL_COLOR
+                        and not channel.execute_if_off_supported
+                    ):
+                        self._GROUP_SUPPORTS_EXECUTE_IF_OFF = False
+                        break
+
         self._DEFAULT_MIN_TRANSITION_TIME = any(  # pylint: disable=invalid-name
             member.device.manufacturer in DEFAULT_MIN_TRANSITION_MANUFACTURERS
             for member in group.members
@@ -950,6 +1090,14 @@ class LightGroup(BaseLight, ZhaGroupEntity):
             CONF_ALWAYS_PREFER_XY_COLOR_MODE,
             True,
         )
+        self._zha_config_group_members_assume_state = async_get_zha_config_value(
+            zha_device.gateway.config_entry,
+            ZHA_OPTIONS,
+            CONF_GROUP_MEMBERS_ASSUME_STATE,
+            True,
+        )
+        if self._zha_config_group_members_assume_state:
+            self._update_group_from_child_delay = ASSUME_UPDATE_GROUP_FROM_CHILD_DELAY
         self._zha_config_enhanced_light_transition = False
         self._attr_color_mode = None
 
@@ -974,8 +1122,13 @@ class LightGroup(BaseLight, ZhaGroupEntity):
 
     async def async_turn_on(self, **kwargs: Any) -> None:
         """Turn the entity on."""
+        # "off with transition" and "off brightness" will get overridden when turning on the group,
+        # but they are needed for setting the assumed member state correctly, so save them here
+        off_brightness = self._off_brightness if self._off_with_transition else None
         await super().async_turn_on(**kwargs)
-        if self._transitioning:
+        if self._zha_config_group_members_assume_state:
+            self._send_member_assume_state_event(True, kwargs, off_brightness)
+        if self.is_transitioning:  # when transitioning, state is refreshed at the end
             return
         if self._debounced_member_refresh:
             await self._debounced_member_refresh.async_call()
@@ -983,33 +1136,27 @@ class LightGroup(BaseLight, ZhaGroupEntity):
     async def async_turn_off(self, **kwargs: Any) -> None:
         """Turn the entity off."""
         await super().async_turn_off(**kwargs)
-        if self._transitioning:
+        if self._zha_config_group_members_assume_state:
+            self._send_member_assume_state_event(False, kwargs)
+        if self.is_transitioning:
             return
         if self._debounced_member_refresh:
             await self._debounced_member_refresh.async_call()
 
-    @callback
-    def async_state_changed_listener(self, event: Event) -> None:
-        """Handle child updates."""
-        if self._transitioning:
-            self.debug("skipping group entity state update during transition")
-            return
-        super().async_state_changed_listener(event)
-
-    async def async_update_ha_state(self, force_refresh: bool = False) -> None:
-        """Update Home Assistant with current state of entity."""
-        if self._transitioning:
-            self.debug("skipping group entity state update during transition")
-            return
-        await super().async_update_ha_state(force_refresh)
-
     async def async_update(self) -> None:
         """Query all members and determine the light group state."""
+        self.debug("updating group state")
         all_states = [self.hass.states.get(x) for x in self._entity_ids]
         states: list[State] = list(filter(None, all_states))
         on_states = [state for state in states if state.state == STATE_ON]
 
         self._attr_state = len(on_states) > 0
+
+        # reset "off with transition" flag if any member is on
+        if self._attr_state:
+            self._off_with_transition = False
+            self._off_brightness = None
+
         self._attr_available = any(state.state != STATE_UNAVAILABLE for state in states)
 
         self._attr_brightness = helpers.reduce_attribute(
@@ -1078,7 +1225,7 @@ class LightGroup(BaseLight, ZhaGroupEntity):
                 set[str], set().union(*all_supported_color_modes)
             )
 
-        self._attr_supported_features = 0
+        self._attr_supported_features = LightEntityFeature(0)
         for support in helpers.find_state_attributes(states, ATTR_SUPPORTED_FEATURES):
             # Merge supported features by emulating support for every feature
             # we find.
@@ -1094,3 +1241,41 @@ class LightGroup(BaseLight, ZhaGroupEntity):
             SIGNAL_LIGHT_GROUP_STATE_CHANGED,
             {"entity_ids": self._entity_ids},
         )
+
+    def _send_member_assume_state_event(
+        self, state, service_kwargs, off_brightness=None
+    ) -> None:
+        """Send an assume event to all members of the group."""
+        update_params = {
+            "state": state,
+            "off_with_transition": self._off_with_transition,
+        }
+
+        # check if the parameters were actually updated in the service call before updating members
+        if light.ATTR_BRIGHTNESS in service_kwargs:  # or off brightness
+            update_params[light.ATTR_BRIGHTNESS] = self._attr_brightness
+        elif off_brightness is not None:
+            # if we turn on the group light with "off brightness", pass that to the members
+            update_params[light.ATTR_BRIGHTNESS] = off_brightness
+
+        if light.ATTR_COLOR_TEMP in service_kwargs:
+            update_params[light.ATTR_COLOR_MODE] = self._attr_color_mode
+            update_params[light.ATTR_COLOR_TEMP] = self._attr_color_temp
+
+        if light.ATTR_XY_COLOR in service_kwargs:
+            update_params[light.ATTR_COLOR_MODE] = self._attr_color_mode
+            update_params[light.ATTR_XY_COLOR] = self._attr_xy_color
+
+        if light.ATTR_HS_COLOR in service_kwargs:
+            update_params[light.ATTR_COLOR_MODE] = self._attr_color_mode
+            update_params[light.ATTR_HS_COLOR] = self._attr_hs_color
+
+        if light.ATTR_EFFECT in service_kwargs:
+            update_params[light.ATTR_EFFECT] = self._attr_effect
+
+        async_dispatcher_send(
+            self.hass,
+            SIGNAL_LIGHT_GROUP_ASSUME_GROUP_STATE,
+            {"entity_ids": self._entity_ids},
+            update_params,
+        )
