@@ -1,6 +1,7 @@
 """Sensors on Zigbee Home Automation networks."""
 from __future__ import annotations
 
+import enum
 import functools
 import numbers
 from typing import TYPE_CHECKING, Any, TypeVar
@@ -20,6 +21,7 @@ from homeassistant.const import (
     CONCENTRATION_PARTS_PER_MILLION,
     LIGHT_LUX,
     PERCENTAGE,
+    SIGNAL_STRENGTH_DECIBELS_MILLIWATT,
     Platform,
     UnitOfApparentPower,
     UnitOfElectricCurrent,
@@ -174,7 +176,7 @@ class Sensor(ZhaEntity, SensorEntity):
         """Handle state update from channel."""
         self.async_write_ha_state()
 
-    def formatter(self, value: int) -> int | float | None:
+    def formatter(self, value: int | enum.IntEnum) -> int | float | str | None:
         """Numeric pass-through formatter."""
         if self._decimals > 0:
             return round(
@@ -183,12 +185,6 @@ class Sensor(ZhaEntity, SensorEntity):
         return round(float(value * self._multiplier) / self._divisor)
 
 
-@MULTI_MATCH(
-    channel_names=CHANNEL_ANALOG_INPUT,
-    manufacturers="LUMI",
-    models={"lumi.plug", "lumi.plug.maus01", "lumi.plug.mmeu01"},
-    stop_on_match_group=CHANNEL_ANALOG_INPUT,
-)
 @MULTI_MATCH(
     channel_names=CHANNEL_ANALOG_INPUT,
     manufacturers="Digi",
@@ -495,7 +491,7 @@ class SmartEnergySummation(SmartEnergyMetering, id_suffix="summation_delivered")
 
 @MULTI_MATCH(
     channel_names=CHANNEL_SMARTENERGY_METERING,
-    models={"TS011F"},
+    models={"TS011F", "ZLinky_TIC"},
     stop_on_match_group=CHANNEL_SMARTENERGY_METERING,
 )
 class PolledSmartEnergySummation(SmartEnergySummation):
@@ -510,6 +506,84 @@ class PolledSmartEnergySummation(SmartEnergySummation):
         await self._channel.async_force_update()
 
 
+@MULTI_MATCH(
+    channel_names=CHANNEL_SMARTENERGY_METERING,
+    models={"ZLinky_TIC"},
+)
+class Tier1SmartEnergySummation(
+    PolledSmartEnergySummation, id_suffix="tier1_summation_delivered"
+):
+    """Tier 1 Smart Energy Metering summation sensor."""
+
+    SENSOR_ATTR: int | str = "current_tier1_summ_delivered"
+    _attr_name: str = "Tier 1 summation delivered"
+
+
+@MULTI_MATCH(
+    channel_names=CHANNEL_SMARTENERGY_METERING,
+    models={"ZLinky_TIC"},
+)
+class Tier2SmartEnergySummation(
+    PolledSmartEnergySummation, id_suffix="tier2_summation_delivered"
+):
+    """Tier 2 Smart Energy Metering summation sensor."""
+
+    SENSOR_ATTR: int | str = "current_tier2_summ_delivered"
+    _attr_name: str = "Tier 2 summation delivered"
+
+
+@MULTI_MATCH(
+    channel_names=CHANNEL_SMARTENERGY_METERING,
+    models={"ZLinky_TIC"},
+)
+class Tier3SmartEnergySummation(
+    PolledSmartEnergySummation, id_suffix="tier3_summation_delivered"
+):
+    """Tier 3 Smart Energy Metering summation sensor."""
+
+    SENSOR_ATTR: int | str = "current_tier3_summ_delivered"
+    _attr_name: str = "Tier 3 summation delivered"
+
+
+@MULTI_MATCH(
+    channel_names=CHANNEL_SMARTENERGY_METERING,
+    models={"ZLinky_TIC"},
+)
+class Tier4SmartEnergySummation(
+    PolledSmartEnergySummation, id_suffix="tier4_summation_delivered"
+):
+    """Tier 4 Smart Energy Metering summation sensor."""
+
+    SENSOR_ATTR: int | str = "current_tier4_summ_delivered"
+    _attr_name: str = "Tier 4 summation delivered"
+
+
+@MULTI_MATCH(
+    channel_names=CHANNEL_SMARTENERGY_METERING,
+    models={"ZLinky_TIC"},
+)
+class Tier5SmartEnergySummation(
+    PolledSmartEnergySummation, id_suffix="tier5_summation_delivered"
+):
+    """Tier 5 Smart Energy Metering summation sensor."""
+
+    SENSOR_ATTR: int | str = "current_tier5_summ_delivered"
+    _attr_name: str = "Tier 5 summation delivered"
+
+
+@MULTI_MATCH(
+    channel_names=CHANNEL_SMARTENERGY_METERING,
+    models={"ZLinky_TIC"},
+)
+class Tier6SmartEnergySummation(
+    PolledSmartEnergySummation, id_suffix="tier6_summation_delivered"
+):
+    """Tier 6 Smart Energy Metering summation sensor."""
+
+    SENSOR_ATTR: int | str = "current_tier6_summ_delivered"
+    _attr_name: str = "Tier 6 summation delivered"
+
+
 @MULTI_MATCH(channel_names=CHANNEL_PRESSURE)
 class Pressure(Sensor):
     """Pressure sensor."""
@@ -755,6 +829,8 @@ class RSSISensor(Sensor, id_suffix="rssi"):
     """RSSI sensor for a device."""
 
     _attr_state_class: SensorStateClass = SensorStateClass.MEASUREMENT
+    _attr_device_class: SensorDeviceClass | None = SensorDeviceClass.SIGNAL_STRENGTH
+    _attr_native_unit_of_measurement: str | None = SIGNAL_STRENGTH_DECIBELS_MILLIWATT
     _attr_entity_category = EntityCategory.DIAGNOSTIC
     _attr_entity_registry_enabled_default = False
     _attr_should_poll = True  # BaseZhaEntity defaults to False
@@ -789,6 +865,8 @@ class LQISensor(RSSISensor, id_suffix="lqi"):
     """LQI sensor for a device."""
 
     _attr_name: str = "LQI"
+    _attr_device_class = None
+    _attr_native_unit_of_measurement = None
 
 
 @MULTI_MATCH(
@@ -870,7 +948,7 @@ class AqaraPetFeederPortionsDispensed(Sensor, id_suffix="portions_dispensed"):
 
 @MULTI_MATCH(channel_names="opple_cluster", models={"aqara.feeder.acn001"})
 class AqaraPetFeederWeightDispensed(Sensor, id_suffix="weight_dispensed"):
-    """Sensor that displays the weight weight dispensed by the pet feeder."""
+    """Sensor that displays the weight dispensed by the pet feeder."""
 
     SENSOR_ATTR = "weight_dispensed"
     _attr_name: str = "Weight dispensed today"
